diff --git a/chrome/content/zotero/bindings/itembox.xml b/chrome/content/zotero/bindings/itembox.xml
index da16443341..3b71860e4a 100644
--- a/chrome/content/zotero/bindings/itembox.xml
+++ b/chrome/content/zotero/bindings/itembox.xml
@@ -443,6 +443,13 @@
label.setAttribute("isButton", true);
label.setAttribute("onclick", "ZoteroPane_Local.loadURI('" + doi + "', event)");
label.setAttribute("tooltiptext", Zotero.getString('locate.online.tooltip'));
+ valueElement.setAttribute('contextmenu', 'zotero-doi-menu');
+
+ var openURLMenuItem = document.getElementById('zotero-doi-menu-view-online');
+ openURLMenuItem.setAttribute("oncommand", "ZoteroPane_Local.loadURI('" + doi + "', event)");
+
+ var copyMenuItem = document.getElementById('zotero-doi-menu-copy');
+ copyMenuItem.setAttribute("oncommand", "Zotero.Utilities.Internal.copyTextToClipboard('" + doi + "')");
}
}
else if (fieldName == 'abstractNote') {
@@ -2361,6 +2368,10 @@
+
+
+
+
diff --git a/chrome/content/zotero/fileInterface.js b/chrome/content/zotero/fileInterface.js
index 3548d93ad7..0b900f4279 100644
--- a/chrome/content/zotero/fileInterface.js
+++ b/chrome/content/zotero/fileInterface.js
@@ -41,15 +41,45 @@ var Zotero_File_Exporter = function() {
* Performs the actual export operation
**/
Zotero_File_Exporter.prototype.save = function() {
- var translation = new Zotero.Translate.Export(),
- me = this;
- translation.getTranslators().then(function(translators) {
- // present options dialog
- var io = {translators:translators}
- window.openDialog("chrome://zotero/content/exportOptions.xul",
- "_blank", "chrome,modal,centerscreen,resizable=no", io);
- if(!io.selectedTranslator) {
- return false;
+ var translation = new Zotero.Translate.Export();
+ var translators = translation.getTranslators();
+
+ // present options dialog
+ var io = {translators:translators}
+ window.openDialog("chrome://zotero/content/exportOptions.xul",
+ "_blank", "chrome,modal,centerscreen,resizable=no", io);
+ if(!io.selectedTranslator) {
+ return false;
+ }
+
+ const nsIFilePicker = Components.interfaces.nsIFilePicker;
+ var fp = Components.classes["@mozilla.org/filepicker;1"]
+ .createInstance(nsIFilePicker);
+ fp.init(window, Zotero.getString("fileInterface.export"), nsIFilePicker.modeSave);
+
+ // set file name and extension
+ if(io.displayOptions.exportFileData) {
+ // if the result will be a folder, don't append any extension or use
+ // filters
+ fp.defaultString = this.name;
+ fp.appendFilters(Components.interfaces.nsIFilePicker.filterAll);
+ } else {
+ // if the result will be a file, append an extension and use filters
+ fp.defaultString = this.name+(io.selectedTranslator.target ? "."+io.selectedTranslator.target : "");
+ fp.defaultExtension = io.selectedTranslator.target;
+ fp.appendFilter(io.selectedTranslator.label, "*."+(io.selectedTranslator.target ? io.selectedTranslator.target : "*"));
+ }
+
+ var rv = fp.show();
+ if (rv == nsIFilePicker.returnOK || rv == nsIFilePicker.returnReplace) {
+ if(this.collection) {
+ translation.setCollection(this.collection);
+ } else if(this.items) {
+ translation.setItems(this.items);
+ } else if(this.libraryID === undefined) {
+ throw new Error('No export configured');
+ } else {
+ translation.setLibraryID(this.libraryID);
}
const nsIFilePicker = Components.interfaces.nsIFilePicker;
@@ -130,7 +160,11 @@ var Zotero_File_Interface = new function() {
*/
function exportFile() {
var exporter = new Zotero_File_Exporter();
- exporter.name = Zotero.getString("pane.collections.library");
+ exporter.libraryID = ZoteroPane_Local.getSelectedLibraryID();
+ if (exporter.libraryID === false) {
+ throw new Error('No library selected');
+ }
+ exporter.name = Zotero.Libraries.getName(exporter.libraryID);
exporter.save();
}
diff --git a/chrome/content/zotero/integration/addCitationDialog.js b/chrome/content/zotero/integration/addCitationDialog.js
index 730a51d172..55bc8e3229 100644
--- a/chrome/content/zotero/integration/addCitationDialog.js
+++ b/chrome/content/zotero/integration/addCitationDialog.js
@@ -115,7 +115,7 @@ var Zotero_Citation_Dialog = new function () {
var i = 0;
for(var value in locators) {
var locator = locators[value];
- var locatorLabel = locator[0].toUpperCase()+locator.substr(1);
+ var locatorLabel = Zotero.getString('citation.locator.'+locator.replace(/\s/g,''));
// add to list of labels
var child = document.createElement("menuitem");
child.setAttribute("value", value);
diff --git a/chrome/content/zotero/integration/quickFormat.js b/chrome/content/zotero/integration/quickFormat.js
index 401d32b2ed..a455f50ef9 100644
--- a/chrome/content/zotero/integration/quickFormat.js
+++ b/chrome/content/zotero/integration/quickFormat.js
@@ -79,8 +79,7 @@ var Zotero_QuickFormat = new function () {
var menu = document.getElementById("locator-label");
var labelList = document.getElementById("locator-label-popup");
for each(var locator in locators) {
- // TODO localize
- var locatorLabel = locator[0].toUpperCase()+locator.substr(1);
+ var locatorLabel = Zotero.getString('citation.locator.'+locator.replace(/\s/g,''));
// add to list of labels
var child = document.createElement("menuitem");
diff --git a/chrome/content/zotero/preferences/preferences_firefox.xul b/chrome/content/zotero/preferences/preferences_firefox.xul
index 07dc62428a..bfb1e50e07 100644
--- a/chrome/content/zotero/preferences/preferences_firefox.xul
+++ b/chrome/content/zotero/preferences/preferences_firefox.xul
@@ -23,7 +23,10 @@
***** END LICENSE BLOCK *****
-->
-
+ %preferencesDTD;
+ %zoteroDTD;
+]>
@@ -64,7 +67,7 @@
@@ -73,7 +76,9 @@
-
+
+
+
diff --git a/chrome/content/zotero/preferences/preferences_proxies.js b/chrome/content/zotero/preferences/preferences_proxies.js
index b0227396f6..6c081a18f5 100644
--- a/chrome/content/zotero/preferences/preferences_proxies.js
+++ b/chrome/content/zotero/preferences/preferences_proxies.js
@@ -55,6 +55,14 @@ Zotero_Preferences.Proxies = {
},
+ /**
+ * Enables UI buttons when proxy is selected
+ */
+ enableProxyButtons: function () {
+ document.getElementById('proxyTree-edit').disabled = false;
+ document.getElementById('proxyTree-delete').disabled = false;
+ },
+
/**
* Adds a proxy to the proxy pane
*/
@@ -138,6 +146,7 @@ Zotero_Preferences.Proxies = {
}
document.getElementById('proxyTree').currentIndex = -1;
+ document.getElementById('proxyTree-edit').disabled = true;
document.getElementById('proxyTree-delete').disabled = true;
document.getElementById('zotero-proxies-transparent').checked = Zotero.Prefs.get("proxies.transparent");
document.getElementById('zotero-proxies-autoRecognize').checked = Zotero.Prefs.get("proxies.autoRecognize");
diff --git a/chrome/content/zotero/recognizePDF.js b/chrome/content/zotero/recognizePDF.js
index 8a1dabb212..1d6e8bffd8 100644
--- a/chrome/content/zotero/recognizePDF.js
+++ b/chrome/content/zotero/recognizePDF.js
@@ -591,7 +591,11 @@ var Zotero_RecognizePDF = new function() {
const lineRe = /^[\s_]*([^\s]+(?: [^\s_]+)+)/;
var cleanedLines = [], cleanedLineLengths = [];
for(var i=0; i 3) {
cleanedLines.push(m[1]);
cleanedLineLengths.push(m[1].length);
diff --git a/chrome/content/zotero/tools/csledit.js b/chrome/content/zotero/tools/csledit.js
index 6a777b480c..1bcbc6a913 100644
--- a/chrome/content/zotero/tools/csledit.js
+++ b/chrome/content/zotero/tools/csledit.js
@@ -64,7 +64,7 @@ var Zotero_CSL_Editor = new function() {
var locators = Zotero.Cite.labels;
for each(var type in locators) {
var locator = type;
- locator = locator[0].toUpperCase()+locator.substr(1);
+ locator = Zotero.getString('citation.locator.'+locator.replace(/\s/g,''));
pageList.appendItem(locator, type);
}
diff --git a/chrome/content/zotero/xpcom/progressWindow.js b/chrome/content/zotero/xpcom/progressWindow.js
index 4ba17faa64..9bbea312f4 100644
--- a/chrome/content/zotero/xpcom/progressWindow.js
+++ b/chrome/content/zotero/xpcom/progressWindow.js
@@ -291,6 +291,7 @@ Zotero.ProgressWindow = function(_window){
this._image.setAttribute("flex", 0);
this._image.style.width = "16px";
this._image.style.backgroundRepeat = "no-repeat";
+ this._image.style.backgroundSize = "16px";
this.setIcon(iconSrc);
this._hbox = _progressWindow.document.createElement("hbox");
diff --git a/chrome/content/zotero/xpcom/storage.js b/chrome/content/zotero/xpcom/storage.js
index 9b98fe7410..a12b0cfccd 100644
--- a/chrome/content/zotero/xpcom/storage.js
+++ b/chrome/content/zotero/xpcom/storage.js
@@ -1476,7 +1476,7 @@ Zotero.Sync.Storage = new function () {
var fileName = entryName;
}
- if (fileName.indexOf('.') == 0) {
+ if (fileName.startsWith('.zotero')) {
Zotero.debug("Skipping " + fileName);
continue;
}
@@ -1621,7 +1621,7 @@ Zotero.Sync.Storage = new function () {
var filesToDelete = [];
var file;
while (file = otherFiles.nextFile) {
- if (file.leafName[0] == '.') {
+ if (file.leafName.startsWith('.zotero')) {
continue;
}
@@ -1722,7 +1722,7 @@ Zotero.Sync.Storage = new function () {
continue;
}
var fileName = file.getRelativeDescriptor(rootDir);
- if (fileName.indexOf('.') == 0) {
+ if (fileName.startsWith('.zotero')) {
Zotero.debug('Skipping file ' + fileName);
continue;
}
diff --git a/chrome/content/zotero/xpcom/translation/translate_item.js b/chrome/content/zotero/xpcom/translation/translate_item.js
index 282df2eeba..32bb58bc0c 100644
--- a/chrome/content/zotero/xpcom/translation/translate_item.js
+++ b/chrome/content/zotero/xpcom/translation/translate_item.js
@@ -736,11 +736,11 @@ Zotero.Translate.ItemGetter.prototype = {
this.numItems = this._itemsLeft.length;
},
- "setAll":function(getChildCollections) {
- this._itemsLeft = Zotero.Items.getAll(0, true);
+ "setAll": function (libraryID, getChildCollections) {
+ this._itemsLeft = Zotero.Items.getAll(libraryID, true);
if(getChildCollections) {
- this._collectionsLeft = Zotero.getCollections();
+ this._collectionsLeft = Zotero.getCollections(null, true, libraryID);
}
this.numItems = this._itemsLeft.length;
diff --git a/chrome/content/zotero/xpcom/utilities_internal.js b/chrome/content/zotero/xpcom/utilities_internal.js
index acf50ce99f..656057f375 100644
--- a/chrome/content/zotero/xpcom/utilities_internal.js
+++ b/chrome/content/zotero/xpcom/utilities_internal.js
@@ -55,6 +55,16 @@ Zotero.Utilities.Internal = {
}),
+ /**
+ * Copy a text string to the clipboard
+ */
+ "copyTextToClipboard":function(str) {
+ Components.classes["@mozilla.org/widget/clipboardhelper;1"]
+ .getService(Components.interfaces.nsIClipboardHelper)
+ .copyString(str);
+ },
+
+
/*
* Adapted from http://developer.mozilla.org/en/docs/nsICryptoHash
*
@@ -792,4 +802,4 @@ Zotero.Utilities.Internal.Base64 = {
return string;
}
- }
\ No newline at end of file
+ }
diff --git a/chrome/content/zotero/xpcom/zotero.js b/chrome/content/zotero/xpcom/zotero.js
index 8defbd6ef1..231705971e 100644
--- a/chrome/content/zotero/xpcom/zotero.js
+++ b/chrome/content/zotero/xpcom/zotero.js
@@ -634,12 +634,12 @@ Components.utils.import("resource://gre/modules/osfile.jsm");
Components.utils.reportError(e); // DEBUG: doesn't always work
if (e.toString().match('newer than SQL file')) {
- let versions = e.toString().match(/\((\d+) < \d+\)/);
+ let versions = e.toString().match(/\((\d+) < (\d+)\)/);
let kbURL = "https://www.zotero.org/support/kb/newer_db_version";
let msg = Zotero.getString('startupError.zoteroVersionIsOlder') + " "
+ Zotero.getString('startupError.zoteroVersionIsOlder.upgrade') + "\n\n"
- + Zotero.getString('startupError.zoteroVersionIsOlder.current', Zotero.version) + "\n"
- + (versions ? "DB: " + versions[1] + "\n\n" : "\n")
+ + Zotero.getString('startupError.zoteroVersionIsOlder.current', Zotero.version)
+ + (versions ? " (" + versions[1] + " < " + versions[2] + ")" : "") + "\n\n"
+ Zotero.getString('general.seeForMoreInformation', kbURL);
Zotero.startupError = msg;
_startupErrorHandler = function() {
diff --git a/chrome/content/zotero/zoteroPane.js b/chrome/content/zotero/zoteroPane.js
index 62e5f25873..17109fb7bf 100644
--- a/chrome/content/zotero/zoteroPane.js
+++ b/chrome/content/zotero/zoteroPane.js
@@ -2297,7 +2297,7 @@ var ZoteroPane = new function()
show = [m.emptyTrash];
}
else if (collectionTreeRow.isGroup()) {
- show = [m.newCollection, m.newSavedSearch, m.sep1, m.showDuplicates, m.showUnfiled];
+ show = [m.newCollection, m.newSavedSearch, m.sep1, m.showDuplicates, m.showUnfiled, m.sep2, m.exportFile];
}
else if (collectionTreeRow.isDuplicates() || collectionTreeRow.isUnfiled()) {
show = [
diff --git a/chrome/locale/af-ZA/zotero/zotero.dtd b/chrome/locale/af-ZA/zotero/zotero.dtd
index 81d96bd20b..d739a0edd1 100644
--- a/chrome/locale/af-ZA/zotero/zotero.dtd
+++ b/chrome/locale/af-ZA/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/ar/zotero/zotero.dtd b/chrome/locale/ar/zotero/zotero.dtd
index 02a362237f..4cce0c09e0 100644
--- a/chrome/locale/ar/zotero/zotero.dtd
+++ b/chrome/locale/ar/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/bg-BG/zotero/zotero.dtd b/chrome/locale/bg-BG/zotero/zotero.dtd
index c9bc933caf..7db4004151 100644
--- a/chrome/locale/bg-BG/zotero/zotero.dtd
+++ b/chrome/locale/bg-BG/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/ca-AD/zotero/zotero.dtd b/chrome/locale/ca-AD/zotero/zotero.dtd
index 9cda030d88..4be36e68bd 100644
--- a/chrome/locale/ca-AD/zotero/zotero.dtd
+++ b/chrome/locale/ca-AD/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/cs-CZ/zotero/zotero.dtd b/chrome/locale/cs-CZ/zotero/zotero.dtd
index 29e503abd1..7e8388e9e0 100644
--- a/chrome/locale/cs-CZ/zotero/zotero.dtd
+++ b/chrome/locale/cs-CZ/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/cs-CZ/zotero/zotero.properties b/chrome/locale/cs-CZ/zotero/zotero.properties
index 21d427ff7b..ff8c87ad29 100644
--- a/chrome/locale/cs-CZ/zotero/zotero.properties
+++ b/chrome/locale/cs-CZ/zotero/zotero.properties
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Odstranit skupinu a synchronizovat
sync.localObject=Lokální objekt
sync.remoteObject=Vzdálený objekt
sync.mergedObject=Sloučený objekt
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Při řešení všech zbývajících konfliktů preferovat místní verzi.
+sync.merge.resolveAllRemote=Při řešení všech zbývajících konfliktů preferovat vzdálenou verzi.
sync.error.usernameNotSet=Uživatelské jméno není nastaveno
diff --git a/chrome/locale/da-DK/zotero/zotero.dtd b/chrome/locale/da-DK/zotero/zotero.dtd
index b63f5a2e3f..6f5bde87cc 100644
--- a/chrome/locale/da-DK/zotero/zotero.dtd
+++ b/chrome/locale/da-DK/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/de/zotero/zotero.dtd b/chrome/locale/de/zotero/zotero.dtd
index e33f8e1b9e..d1571e47fc 100644
--- a/chrome/locale/de/zotero/zotero.dtd
+++ b/chrome/locale/de/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/de/zotero/zotero.properties b/chrome/locale/de/zotero/zotero.properties
index f119d92f14..554bdc8d24 100644
--- a/chrome/locale/de/zotero/zotero.properties
+++ b/chrome/locale/de/zotero/zotero.properties
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Gruppen entfernen und synchronisieren
sync.localObject=Lokales Objekt
sync.remoteObject=Remote-Objekt
sync.mergedObject=Zusammengeführtes Objekt
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Lokal gespeicherte Version für alle weiteren Konflikte verwenden
+sync.merge.resolveAllRemote=Auf dem Server gespeicherte Version für alle weiteren Konflikte verwenden
sync.error.usernameNotSet=Benutzername nicht definiert
diff --git a/chrome/locale/el-GR/zotero/zotero.dtd b/chrome/locale/el-GR/zotero/zotero.dtd
index 549fe59009..0601e416e2 100644
--- a/chrome/locale/el-GR/zotero/zotero.dtd
+++ b/chrome/locale/el-GR/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/en-US/zotero/zotero.dtd b/chrome/locale/en-US/zotero/zotero.dtd
index c901be1921..4317b24131 100644
--- a/chrome/locale/en-US/zotero/zotero.dtd
+++ b/chrome/locale/en-US/zotero/zotero.dtd
@@ -128,6 +128,8 @@
+
+
@@ -190,9 +192,6 @@
-
-
-
diff --git a/chrome/locale/en-US/zotero/zotero.properties b/chrome/locale/en-US/zotero/zotero.properties
index 97a4e59094..a548e5deba 100644
--- a/chrome/locale/en-US/zotero/zotero.properties
+++ b/chrome/locale/en-US/zotero/zotero.properties
@@ -680,6 +680,22 @@ citation.showEditor = Show Editor…
citation.hideEditor = Hide Editor…
citation.citations = Citations
citation.notes = Notes
+citation.locator.page = Page
+citation.locator.book = Book
+citation.locator.chapter = Chapter
+citation.locator.column = Column
+citation.locator.figure = Figure
+citation.locator.folio = Folio
+citation.locator.issue = Issue
+citation.locator.line = Line
+citation.locator.note = Note
+citation.locator.opus = Opus
+citation.locator.paragraph = Paragraph
+citation.locator.part = Part
+citation.locator.section = Section
+citation.locator.subverbo = Sub verbo
+citation.locator.volume = Volume
+citation.locator.verse = Verse
report.title.default = Zotero Report
report.parentItem = Parent Item:
diff --git a/chrome/locale/es-ES/zotero/zotero.dtd b/chrome/locale/es-ES/zotero/zotero.dtd
index be02c4429c..98705d6385 100644
--- a/chrome/locale/es-ES/zotero/zotero.dtd
+++ b/chrome/locale/es-ES/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/es-ES/zotero/zotero.properties b/chrome/locale/es-ES/zotero/zotero.properties
index 4bb73516fe..9c2f3ff2a3 100644
--- a/chrome/locale/es-ES/zotero/zotero.properties
+++ b/chrome/locale/es-ES/zotero/zotero.properties
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Quitar grupos y sincronizar
sync.localObject=Objeto local
sync.remoteObject=Objeto remoto
sync.mergedObject=Unir objeto
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Utilice la versión local para todos los conflictos restantes
+sync.merge.resolveAllRemote=Utilice la versión remota para todos los conflictos restantes
sync.error.usernameNotSet=Nombre de usuario no provisto
diff --git a/chrome/locale/et-EE/zotero/zotero.dtd b/chrome/locale/et-EE/zotero/zotero.dtd
index 66af42ea2e..9735da8688 100644
--- a/chrome/locale/et-EE/zotero/zotero.dtd
+++ b/chrome/locale/et-EE/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/eu-ES/zotero/zotero.dtd b/chrome/locale/eu-ES/zotero/zotero.dtd
index 6599093ac7..64104f3310 100644
--- a/chrome/locale/eu-ES/zotero/zotero.dtd
+++ b/chrome/locale/eu-ES/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/fa/zotero/zotero.dtd b/chrome/locale/fa/zotero/zotero.dtd
index 52ecd7216a..0ea7303c72 100644
--- a/chrome/locale/fa/zotero/zotero.dtd
+++ b/chrome/locale/fa/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/fi-FI/zotero/zotero.dtd b/chrome/locale/fi-FI/zotero/zotero.dtd
index a387521c4f..455ac5a4ff 100644
--- a/chrome/locale/fi-FI/zotero/zotero.dtd
+++ b/chrome/locale/fi-FI/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/fr-FR/zotero/zotero.dtd b/chrome/locale/fr-FR/zotero/zotero.dtd
index 65455bae67..ede77d5a06 100644
--- a/chrome/locale/fr-FR/zotero/zotero.dtd
+++ b/chrome/locale/fr-FR/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/fr-FR/zotero/zotero.properties b/chrome/locale/fr-FR/zotero/zotero.properties
index 481126775f..2c6b8722cc 100644
--- a/chrome/locale/fr-FR/zotero/zotero.properties
+++ b/chrome/locale/fr-FR/zotero/zotero.properties
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Retirer les groupes et synchroniser
sync.localObject=Objet local
sync.remoteObject=Objet distant
sync.mergedObject=Objet fusionné
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Utiliser la version locale pour tous les conflits restants
+sync.merge.resolveAllRemote=Utiliser la version distante pour tous les conflits restants
sync.error.usernameNotSet=Identifiant non défini
diff --git a/chrome/locale/gl-ES/zotero/zotero.dtd b/chrome/locale/gl-ES/zotero/zotero.dtd
index 6e22ad714f..6839374d97 100644
--- a/chrome/locale/gl-ES/zotero/zotero.dtd
+++ b/chrome/locale/gl-ES/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/he-IL/zotero/zotero.dtd b/chrome/locale/he-IL/zotero/zotero.dtd
index 4fd30269ba..66e6444be4 100644
--- a/chrome/locale/he-IL/zotero/zotero.dtd
+++ b/chrome/locale/he-IL/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/hr-HR/zotero/zotero.dtd b/chrome/locale/hr-HR/zotero/zotero.dtd
index a153f114c5..c5501bc7e6 100644
--- a/chrome/locale/hr-HR/zotero/zotero.dtd
+++ b/chrome/locale/hr-HR/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/hu-HU/zotero/zotero.dtd b/chrome/locale/hu-HU/zotero/zotero.dtd
index 2c4cce102a..5d5d76dc04 100644
--- a/chrome/locale/hu-HU/zotero/zotero.dtd
+++ b/chrome/locale/hu-HU/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/hu-HU/zotero/zotero.properties b/chrome/locale/hu-HU/zotero/zotero.properties
index c113c7392d..fb9006d0fd 100644
--- a/chrome/locale/hu-HU/zotero/zotero.properties
+++ b/chrome/locale/hu-HU/zotero/zotero.properties
@@ -570,8 +570,8 @@ zotero.preferences.wordProcessors.installationSuccess=A telepítés sikeresen be
zotero.preferences.wordProcessors.installationError=Installation could not be completed because an error occurred. Please ensure that %1$S is closed, and then restart %2$S.
zotero.preferences.wordProcessors.installed=The %S add-in is currently installed.
zotero.preferences.wordProcessors.notInstalled=The %S add-in is not currently installed.
-zotero.preferences.wordProcessors.install=Install %S Add-in
-zotero.preferences.wordProcessors.reinstall=Reinstall %S Add-in
+zotero.preferences.wordProcessors.install=%S kiegészítő telepítése
+zotero.preferences.wordProcessors.reinstall=%S kiegészítő újratelepítése
zotero.preferences.wordProcessors.installing=Telepítés %S…
zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S is incompatible with versions of %3$S before %4$S. Please remove %3$S, or download the latest version from %5$S.
zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S requires %3$S %4$S or later to run. Please download the latest version of %3$S from %5$S.
diff --git a/chrome/locale/id-ID/zotero/zotero.dtd b/chrome/locale/id-ID/zotero/zotero.dtd
index 470f3e9b08..4510a51dab 100644
--- a/chrome/locale/id-ID/zotero/zotero.dtd
+++ b/chrome/locale/id-ID/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/is-IS/zotero/zotero.dtd b/chrome/locale/is-IS/zotero/zotero.dtd
index 36d3f5eed2..7ba835b706 100644
--- a/chrome/locale/is-IS/zotero/zotero.dtd
+++ b/chrome/locale/is-IS/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/it-IT/zotero/zotero.dtd b/chrome/locale/it-IT/zotero/zotero.dtd
index 8afd8ec749..3ec2b126fa 100644
--- a/chrome/locale/it-IT/zotero/zotero.dtd
+++ b/chrome/locale/it-IT/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/ja-JP/zotero/zotero.dtd b/chrome/locale/ja-JP/zotero/zotero.dtd
index 57ac796b10..ed4840fb26 100644
--- a/chrome/locale/ja-JP/zotero/zotero.dtd
+++ b/chrome/locale/ja-JP/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/km/zotero/zotero.dtd b/chrome/locale/km/zotero/zotero.dtd
index 209d808542..c6b9e45929 100644
--- a/chrome/locale/km/zotero/zotero.dtd
+++ b/chrome/locale/km/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/ko-KR/zotero/zotero.dtd b/chrome/locale/ko-KR/zotero/zotero.dtd
index 55a2177d52..9c23517098 100644
--- a/chrome/locale/ko-KR/zotero/zotero.dtd
+++ b/chrome/locale/ko-KR/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/lt-LT/zotero/preferences.dtd b/chrome/locale/lt-LT/zotero/preferences.dtd
index a1f42cfed2..ed775b7c14 100644
--- a/chrome/locale/lt-LT/zotero/preferences.dtd
+++ b/chrome/locale/lt-LT/zotero/preferences.dtd
@@ -160,7 +160,7 @@
-
+
@@ -201,6 +201,6 @@
-
-
+
+
diff --git a/chrome/locale/lt-LT/zotero/zotero.dtd b/chrome/locale/lt-LT/zotero/zotero.dtd
index 92126e715d..7e339699f5 100644
--- a/chrome/locale/lt-LT/zotero/zotero.dtd
+++ b/chrome/locale/lt-LT/zotero/zotero.dtd
@@ -6,8 +6,8 @@
-
-
+
+
@@ -125,7 +125,9 @@
-
+
+
+
@@ -287,6 +289,6 @@
-
-
-
+
+
+
diff --git a/chrome/locale/lt-LT/zotero/zotero.properties b/chrome/locale/lt-LT/zotero/zotero.properties
index c3c2be77ea..e0f847dfa6 100644
--- a/chrome/locale/lt-LT/zotero/zotero.properties
+++ b/chrome/locale/lt-LT/zotero/zotero.properties
@@ -42,7 +42,7 @@ general.create=Sukurti
general.delete=Šalinti
general.moreInformation=Daugiau informacijos
general.seeForMoreInformation=Daugiau informacijos %S
-general.open=Open %S
+general.open=Atverti „%S“
general.enable=Įgalinti
general.disable=Uždrausti
general.remove=Pašalinti
@@ -196,19 +196,19 @@ tagColorChooser.maxTags=Spalvas galite priskirti ne daugiau kaip %S gairėms(-i
pane.items.loading=Įkeliamas įrašų sąrašas...
pane.items.columnChooser.moreColumns=Papildomi stulpeliai
pane.items.columnChooser.secondarySort=Antrinis rūšiavimas (%S)
-pane.items.attach.link.uri.unrecognized=Zotero did not recognize the URI you entered. Please check the address and try again.
-pane.items.attach.link.uri.file=To attach a link to a file, please use “%S”.
+pane.items.attach.link.uri.unrecognized=Zotero neatpažino įvestos URI nuorodos. Patikrinkite adresą ir bandykite iš naujo.
+pane.items.attach.link.uri.file=Norėdami įtraukti nuorodą iki rinkmenos, rinkitės „%S“.
pane.items.trash.title=Perkelti į šiukšlinę
pane.items.trash=Tikrai norite pasirinktą įrašą perkelti į šiukšlinę?
pane.items.trash.multiple=Tikrai norite pasirinktus įrašus perkelti į šiukšlinę?
pane.items.delete.title=Šalinti
pane.items.delete=Tikrai norite pašalinti pasirinktą įrašą?
pane.items.delete.multiple=Tikrai norite pašalinti pasirinktus įrašus?
-pane.items.remove.title=Remove from Collection
-pane.items.remove=Are you sure you want to remove the selected item from this collection?
-pane.items.remove.multiple=Are you sure you want to remove the selected items from this collection?
-pane.items.menu.remove=Remove Item from Collection…
-pane.items.menu.remove.multiple=Remove Items from Collection…
+pane.items.remove.title=Pašalinti iš rinkinio
+pane.items.remove=Tikrai pašalinti pasirinktą įrašą iš šio rinkinio?
+pane.items.remove.multiple=Tikrai pašalinti pasirinktus įrašus iš šio rinkinio?
+pane.items.menu.remove=Įrašą pašalinti iš rinkinio...
+pane.items.menu.remove.multiple=Įrašus pašalinti iš rinkinio...
pane.items.menu.moveToTrash=Įrašą perkelti į šiukšlinę...
pane.items.menu.moveToTrash.multiple=Įrašus perkelti į šiukšlinę...
pane.items.menu.export=Eksportuoti įrašą...
@@ -225,7 +225,7 @@ pane.items.menu.createParent=Sukurti aukštesnio lygio įrašą
pane.items.menu.createParent.multiple=Sukurti aukštesnio lygio įrašus
pane.items.menu.renameAttachments=Failą pervadinti pagal meta duomenis
pane.items.menu.renameAttachments.multiple=Failus pervadinti pagal meta duomenis
-pane.items.showItemInLibrary=Show Item in Library
+pane.items.showItemInLibrary=Parodyti bibliotekoje
pane.items.letter.oneParticipant=Laiškas, kurį gavo %S
pane.items.letter.twoParticipants=Laiškas, kurį gavo %S ir %S
@@ -566,15 +566,15 @@ zotero.preferences.export.quickCopy.exportFormats=Eksportavimo formatai
zotero.preferences.export.quickCopy.instructions=Greitasis kopijavimas leidžia nuspaudus %S klavišus nukopijuoti pasirinktus įrašus į iškarpinę arba nutempti įrašus į teksto lauką tinklalapyje.
zotero.preferences.export.quickCopy.citationInstructions=Su bibliografijos stiliais galite kopijuoti citavimus arba išnašas spausdami %S arba laikydami Lyg2 (Shift) klavišą prieš tempdami įrašus.
-zotero.preferences.wordProcessors.installationSuccess=Installation was successful.
-zotero.preferences.wordProcessors.installationError=Installation could not be completed because an error occurred. Please ensure that %1$S is closed, and then restart %2$S.
-zotero.preferences.wordProcessors.installed=The %S add-in is currently installed.
-zotero.preferences.wordProcessors.notInstalled=The %S add-in is not currently installed.
-zotero.preferences.wordProcessors.install=Install %S Add-in
-zotero.preferences.wordProcessors.reinstall=Reinstall %S Add-in
-zotero.preferences.wordProcessors.installing=Installing %S…
-zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S is incompatible with versions of %3$S before %4$S. Please remove %3$S, or download the latest version from %5$S.
-zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S requires %3$S %4$S or later to run. Please download the latest version of %3$S from %5$S.
+zotero.preferences.wordProcessors.installationSuccess=Įdiegta sėkmingai.
+zotero.preferences.wordProcessors.installationError=Įdiegti nepavyko. Pirma užverkite %1$S , tuomet iš naujo paleiskite %2$S.
+zotero.preferences.wordProcessors.installed=Papildinys „%S“ jau įdiegtas.
+zotero.preferences.wordProcessors.notInstalled=Papildinys „%S“ neįdiegtas.
+zotero.preferences.wordProcessors.install=Įdiegti papildinį „%S“
+zotero.preferences.wordProcessors.reinstall=Iš naujo įdiegti papildinį „%S“
+zotero.preferences.wordProcessors.installing=Diegiama: „%S“...
+zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S nėra suderinama su %3$S versijomis iki %4$S. Pašalinkite %3$S, arba įdiekite naujausią versiją iš %5$S.
+zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S reikalauja %3$S %4$S arba vėlesnės versijos. Naujausią %3$S versiją parsisiųskite iš %5$S.
zotero.preferences.styles.addStyle=Įtraukti stilių
@@ -738,7 +738,7 @@ integration.missingItem.multiple=Pažymėto citavimo „%1$S“ įrašo nebėra
integration.missingItem.description=Spausdami „Ne“ ištrinsite citavimo laukų kodus, turinčius šį įrašą, tad išsaugosite citavimo tekstą, bet pašalinsite jį iš bibliografijos.
integration.removeCodesWarning=Pašalinus laukų kodus, Zotero programai šiame dokumente nebeleisite atnaujinti citavimų ir bibliografijos. Tikrai norite tęsti?
integration.upgradeWarning=Jūsų dokumentą reikia negrįžtamai atnaujinti tam, kad su juo galėtų dirbti Zotero 2.1 ir vėlesnės versijos. Prieš tęsiant patariame pasidaryti atsarginę kopiją. Tikrai norite tęsti?
-integration.error.newerDocumentVersion=Your document was created with a newer version of Zotero (%1$S) than the currently installed version (%2$S). Please upgrade Zotero before editing this document.
+integration.error.newerDocumentVersion=Dokumentą sukūrėte naujesne Zotero versija (%1$S) negu šiuo metu naudojate (%2$S). Prieš redaguodami šį dokumentą, atnaujinkite Zotero.
integration.corruptField=Buvo sugadintas šį citavimą atitinkantis Zotero lauko kodas, kuris Zotero programai nurodo įrašų atitikmenis bibliotekoje. Ar norėtumėte įrašą pasirinkti iš naujo?
integration.corruptField.description=Spausdami „Ne“ ištrinsite citavimo laukų kodus, turinčius šį įrašą, tad išsaugosite citavimo tekstą, bet galbūt pašalinsite jį iš savo bibliografijos.
integration.corruptBibliography=Jūsų bibliografijos Zotero lauko kodas sugadintas. Ar norėtumėte, kad Zotero programa išvalytų šį lauko kodą ir sukurtų naują bibliografiją?
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Pašalinti grupes ir sinchronizuoti
sync.localObject=Vietinis objektas
sync.remoteObject=Nutolęs objektas
sync.mergedObject=Apjungtas objektas
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Likusiuose konfliktuose pasirinkti vietinę versiją
+sync.merge.resolveAllRemote=Likusiuose konfliktuose pasirinkti nuotolinę versiją
sync.error.usernameNotSet=Nenurodytas naudotojo vardas
@@ -988,11 +988,11 @@ firstRunGuidance.quickFormatMac=Įveskite ieškomą pavadinimą arba autorių.\n
firstRunGuidance.toolbarButton.new=Čia spragtelėję arba nuspaudę %S klavišus, atversite Zotero.
firstRunGuidance.toolbarButton.upgrade=Nuo šiol „Zotero“ ženkliuką rasite Firefox įrankinėje. „Zotero“ atversite spustelėję ženkliuką arba nuspaudę %S klavišus.
-styles.bibliography=Bibliography
-styles.editor.save=Save Citation Style
-styles.editor.warning.noItems=No items selected in Zotero.
-styles.editor.warning.parseError=Error parsing style:
-styles.editor.warning.renderError=Error generating citations and bibliography:
-styles.editor.output.individualCitations=Individual Citations
-styles.editor.output.singleCitation=Single Citation (with position "first")
-styles.preview.instructions=Select one or more items in Zotero and click the "Refresh" button to see how these items are rendered by the installed CSL citation styles.
+styles.bibliography=Bibliografija
+styles.editor.save=Įrašyti citavimo stilių
+styles.editor.warning.noItems=Zotero lange nepasirinkote nė vieno įrašo.
+styles.editor.warning.parseError=Klaida apdorojant stilių:
+styles.editor.warning.renderError=Klaida sukuriant citavimus ir bibliografiją:
+styles.editor.output.individualCitations=Citavimas pavieniui
+styles.editor.output.singleCitation=Citavimas bendrai (pirmoje padėtyje)
+styles.preview.instructions=Zotero lange pažymėję vieną ar kelis įrašus, nuspauskite mygtuką „Atnaujinti“ – tuomet galėsite peržiūrėti, kaip tie įrašai atrodys pritaikius įdiegtus CSL citavimo stilius.
diff --git a/chrome/locale/mn-MN/zotero/zotero.dtd b/chrome/locale/mn-MN/zotero/zotero.dtd
index 73e3842e2a..269a1169be 100644
--- a/chrome/locale/mn-MN/zotero/zotero.dtd
+++ b/chrome/locale/mn-MN/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/nb-NO/zotero/zotero.dtd b/chrome/locale/nb-NO/zotero/zotero.dtd
index aeb17db5b4..42ffdf247c 100644
--- a/chrome/locale/nb-NO/zotero/zotero.dtd
+++ b/chrome/locale/nb-NO/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/nl-NL/zotero/zotero.dtd b/chrome/locale/nl-NL/zotero/zotero.dtd
index a298ae3472..e08d0fe87b 100644
--- a/chrome/locale/nl-NL/zotero/zotero.dtd
+++ b/chrome/locale/nl-NL/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/nn-NO/zotero/zotero.dtd b/chrome/locale/nn-NO/zotero/zotero.dtd
index 8c6dc3aad1..069fbb973d 100644
--- a/chrome/locale/nn-NO/zotero/zotero.dtd
+++ b/chrome/locale/nn-NO/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/pl-PL/zotero/preferences.dtd b/chrome/locale/pl-PL/zotero/preferences.dtd
index 470a4fd8be..7d8ef99a21 100644
--- a/chrome/locale/pl-PL/zotero/preferences.dtd
+++ b/chrome/locale/pl-PL/zotero/preferences.dtd
@@ -81,7 +81,7 @@
-
+
@@ -167,7 +167,7 @@
-
+
@@ -177,7 +177,7 @@
-
+
@@ -188,9 +188,9 @@
-
-
-
+
+
+
diff --git a/chrome/locale/pl-PL/zotero/zotero.dtd b/chrome/locale/pl-PL/zotero/zotero.dtd
index e8429892d0..a55d5a27f4 100644
--- a/chrome/locale/pl-PL/zotero/zotero.dtd
+++ b/chrome/locale/pl-PL/zotero/zotero.dtd
@@ -26,14 +26,14 @@
-
+
-
+
@@ -86,7 +86,7 @@
-
+
@@ -112,7 +112,7 @@
-
+
@@ -126,6 +126,8 @@
+
+
@@ -157,7 +159,7 @@
-
+
@@ -172,7 +174,7 @@
-
+
@@ -207,13 +209,13 @@
-
+
-
+
@@ -235,7 +237,7 @@
-
+
@@ -266,7 +268,7 @@
-
+
@@ -285,7 +287,7 @@
-
+
diff --git a/chrome/locale/pl-PL/zotero/zotero.properties b/chrome/locale/pl-PL/zotero/zotero.properties
index a00ee0f139..d3c5371e6f 100644
--- a/chrome/locale/pl-PL/zotero/zotero.properties
+++ b/chrome/locale/pl-PL/zotero/zotero.properties
@@ -46,7 +46,7 @@ general.open=Otwórz %S
general.enable=Włącz
general.disable=Wyłącz
general.remove=Usuń
-general.reset=Resetuj
+general.reset=Przywróć
general.hide=Ukryj
general.quit=Wyjdź
general.useDefault=Użyj domyślnych
@@ -96,9 +96,9 @@ errorReport.repoCannotBeContacted=Nie można połączyć się z repozytorium
attachmentBasePath.selectDir=Wybierz katalog podstawowy
attachmentBasePath.chooseNewPath.title=Potwierdź nowy katalog podstawowy
attachmentBasePath.chooseNewPath.message=Linked file attachments below this directory will be saved using relative paths.
-attachmentBasePath.chooseNewPath.existingAttachments.singular=One existing attachment was found within the new base directory.
-attachmentBasePath.chooseNewPath.existingAttachments.plural=%S existing attachments were found within the new base directory.
-attachmentBasePath.chooseNewPath.button=Zmień ustawienie katalogu podstawowego
+attachmentBasePath.chooseNewPath.existingAttachments.singular=W nowym katalogu podstawowym znaleziono jeden istniejący załącznik.
+attachmentBasePath.chooseNewPath.existingAttachments.plural=W nowym katalogu podstawowym znaleziono %S istniejących załączników.
+attachmentBasePath.chooseNewPath.button=Zmień katalog podstawowy
attachmentBasePath.clearBasePath.title=Przywróć absolutne ścieżki
attachmentBasePath.clearBasePath.message=New linked file attachments will be saved using absolute paths.
attachmentBasePath.clearBasePath.existingAttachments.singular=One existing attachment within the old base directory will be converted to use an absolute path.
@@ -197,7 +197,7 @@ pane.items.loading=Wczytywanie listy elementów...
pane.items.columnChooser.moreColumns=Więcej kolumn
pane.items.columnChooser.secondarySort=Sortowanie drugorzędowe (%S)
pane.items.attach.link.uri.unrecognized=Zotero nie rozpoznaje wprowadzonego URI. Proszę sprawdzić adres i spróbować ponownie.
-pane.items.attach.link.uri.file=Aby dołączyć odsyłacz do pliku, użyj proszę "%S".
+pane.items.attach.link.uri.file=Aby dołączyć odnośnik do pliku, użyj proszę "%S".
pane.items.trash.title=Przenieś do Kosza
pane.items.trash=Czy na pewno przenieść zaznaczony element do Kosza?
pane.items.trash.multiple=Czy na pewno przenieść zaznaczone elementy do Kosza?
@@ -477,7 +477,7 @@ fileTypes.document=Dokument
save.attachment=Zapisywanie zrzutu ekranu...
save.link=Zapisywanie odnośnika...
-save.link.error=Podczas zapisywania tego odsyłacza wystąpił błąd.
+save.link.error=Podczas zapisywania tego odnośnika wystąpił błąd.
save.error.cannotMakeChangesToCollection=Nie możesz zmieniać aktualnie wybranej kolekcji.
save.error.cannotAddFilesToCollection=Nie możesz dodać plików do aktualnie wybranej kolekcji.
@@ -509,10 +509,10 @@ db.dbRestored=Baza danych Zotero "%1$S" jest prawdopodobnie uszkodzona.\n\nDane
db.dbRestoreFailed=Baza danych Zotero "%S" jest prawdopodobnie uszkodzona.\n\nPróba odtworzenia danych z ostatniej utworzonej kopii zapasowej nie powiodła się.\nUtworzono nowy plik bazy danych. Uszkodzony plik został zapisany w katalogu Zotero.
db.integrityCheck.passed=Baza danych nie zawiera błędów.
-db.integrityCheck.failed=Baza danych Zotero zawiera błędy!
+db.integrityCheck.failed=Baza danych Zotero zawiera błędy.
db.integrityCheck.dbRepairTool=Możesz użyć narzędzia naprawy bazy danych na http://zotero.org/utils/dbfix, aby spróbować skorygować te błędy.
db.integrityCheck.repairAttempt=Zotero może spróbować naprawić te błędy.
-db.integrityCheck.appRestartNeeded=Należy uruchomić ponownie %S .
+db.integrityCheck.appRestartNeeded=Należy uruchomić ponownie %S.
db.integrityCheck.fixAndRestart=Napraw błędy i uruchom ponownie %S
db.integrityCheck.errorsFixed=Błędy w twojej bazie danych Zotero zostały naprawione.
db.integrityCheck.errorsNotFixed=Nie można było naprawić błędów w twojej bazie danych.
@@ -521,22 +521,22 @@ db.integrityCheck.reportInForums=Możesz przesłać opis tego problemu na Forum
zotero.preferences.update.updated=Zaktualizowano
zotero.preferences.update.upToDate=Aktualne
zotero.preferences.update.error=Błąd
-zotero.preferences.launchNonNativeFiles=Otwieraj PDFy i i inne pliki za pomocą %S jeśli to możliwe.
-zotero.preferences.openurl.resolversFound.zero=Nie znaleziono resolwerów
-zotero.preferences.openurl.resolversFound.singular=Znaleziono %S resolwer
-zotero.preferences.openurl.resolversFound.plural=Znaleziono %S resolwery(ów)
+zotero.preferences.launchNonNativeFiles=Otwieraj PDFy i i inne pliki za pomocą %S jeśli to możliwe
+zotero.preferences.openurl.resolversFound.zero=Nie znaleziono usług
+zotero.preferences.openurl.resolversFound.singular=Znaleziono %S usługi
+zotero.preferences.openurl.resolversFound.plural=Znaleziono %S usług
zotero.preferences.sync.purgeStorage.title=Czy usunąć pliku załączników na serwerach Zotero?
-zotero.preferences.sync.purgeStorage.desc=If you plan to use WebDAV for file syncing and you previously synced attachment files in My Library to the Zotero servers, you can purge those files from the Zotero servers to give you more storage space for groups.\n\nYou can purge files at any time from your account settings on zotero.org.
+zotero.preferences.sync.purgeStorage.desc=Jeśli planujesz używać protokołu WebDAV do synchronizacji plików, a wcześniej synchronizowałeś swoje pliki załączników w "Mojej bibliotece" na serwery Zotero, możesz usunąć te pliki z serwerów Zotero aby uzyskać więcej przestrzeni przechowywania dla grup.\n\nMożesz też usunąć pliki później za pomocą ustawień swojego konta na zotero.org.
zotero.preferences.sync.purgeStorage.confirmButton=Usuń pliki teraz
zotero.preferences.sync.purgeStorage.cancelButton=Nie usuwaj
zotero.preferences.sync.reset.userInfoMissing=Przed użyciem opcji przywracania należy podać nazwę użytkownika i hasło w zakładce %$.
-zotero.preferences.sync.reset.restoreFromServer=Wszystkie dane w tej kopii Zotero zostaną usunięte i zastąpione danymi należącymi do użytkownika '%S' na serwerze Zotero.
+zotero.preferences.sync.reset.restoreFromServer=Wszystkie dane w tej kopii Zotero zostaną usunięte i zastąpione danymi należącymi do użytkownika "%S" na serwerze Zotero.
zotero.preferences.sync.reset.replaceLocalData=Zastąp lokalne dane
zotero.preferences.sync.reset.restartToComplete=Firefox musi być uruchomiony ponownie aby zakończyć proces przywracania.
-zotero.preferences.sync.reset.restoreToServer=Wszystkie dane należące do użytkownika '%S' na serwerze Zotero zostaną usunięte i zastąpione danymi z tej kopii Zotero.\n\nW zależności od rozmiaru twojej biblioteki, może nastąpić przerwa zanim twoje dane będą dostępne na serwerze.
+zotero.preferences.sync.reset.restoreToServer=Wszystkie dane należące do użytkownika "%S" na serwerze Zotero zostaną usunięte i zastąpione danymi z tej kopii Zotero.\n\nW zależności od rozmiaru twojej biblioteki, może nastąpić przerwa zanim twoje dane będą dostępne na serwerze.
zotero.preferences.sync.reset.replaceServerData=Zastąp dane na serwerze
-zotero.preferences.sync.reset.fileSyncHistory=All file sync history will be cleared.\n\nAny local attachment files that do not exist on the storage server will be uploaded on the next sync.
+zotero.preferences.sync.reset.fileSyncHistory=Cała historia synchronizacji plików będzie wyczyszczona.\n\nWszystkie lokalne załączniki plików, które nie istnieją na serwerze przechowywania będą przesłane podczas następnej synchronizacji.
zotero.preferences.search.rebuildIndex=Odbuduj indeks
zotero.preferences.search.rebuildWarning=Czy chcesz odbudować cały indeks? Może to potrwać chwilę.\n\nAby zindeksować elementy, które nie zostały jeszcze zindeksowane, użyj %S.
@@ -567,22 +567,22 @@ zotero.preferences.export.quickCopy.instructions=Szybka kopia pozwala na skopiow
zotero.preferences.export.quickCopy.citationInstructions=W przypadku stylów bibliograficznych możesz skopiować cytowania lub przypisy wciskając %S lub przytrzymując klawisz Shift przed ich przeciągnięciem.
zotero.preferences.wordProcessors.installationSuccess=Instalacja zakończona powodzeniem.
-zotero.preferences.wordProcessors.installationError=Installation could not be completed because an error occurred. Please ensure that %1$S is closed, and then restart %2$S.
+zotero.preferences.wordProcessors.installationError=Instalacja nie może być ukończona z powodu błędu. Proszę upewnić się, że %1$S jest zamknięty i ponownie uruchomić %2$S.
zotero.preferences.wordProcessors.installed=Dodatek %S jest już zainstalowany.
zotero.preferences.wordProcessors.notInstalled=Dodatek %S nie jest aktualnie zainstalowany.
zotero.preferences.wordProcessors.install=Zainstaluj dodatek %S
zotero.preferences.wordProcessors.reinstall=Zainstaluj ponownie dodatek %S
zotero.preferences.wordProcessors.installing=Instalowanie %S...
-zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S is incompatible with versions of %3$S before %4$S. Please remove %3$S, or download the latest version from %5$S.
-zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S requires %3$S %4$S or later to run. Please download the latest version of %3$S from %5$S.
+zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S nie jest zgodny z wersjami %3$S wcześniejszymi niż %4$S. Proszę usuń %3$S lub pobierz najnowszą wersję z %5$S.
+zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S wymaga do uruchomienia %3$S %4$S lub nowszej wersji. Pobierz proszę najnowszą wersję %3$S z %5$S.
zotero.preferences.styles.addStyle=Dodaj styl
-zotero.preferences.advanced.resetTranslatorsAndStyles=Resetuj translatory i style
+zotero.preferences.advanced.resetTranslatorsAndStyles=Przywróć translatory i style
zotero.preferences.advanced.resetTranslatorsAndStyles.changesLost=Nowe lub zmodyfikowane translatory i style zostaną utracone.
-zotero.preferences.advanced.resetTranslators=Resetuj translatory
+zotero.preferences.advanced.resetTranslators=Przywróć translatory
zotero.preferences.advanced.resetTranslators.changesLost=Nowe lub zmodyfikowane translatory zostaną utracone.
-zotero.preferences.advanced.resetStyles=Resetuj style
+zotero.preferences.advanced.resetStyles=Przywróć style
zotero.preferences.advanced.resetStyles.changesLost=Nowe lub zmodyfikowane style zostaną utracone.
zotero.preferences.advanced.debug.title=Informacja debugowania została wysłana.
@@ -612,8 +612,8 @@ quickSearch.mode.titleCreatorYear=Tytuł, Twórca, Rok
quickSearch.mode.fieldsAndTags=Wszystkie pola i etykiety
quickSearch.mode.everything=Wszystko
-advancedSearchMode=Wyszukiwanie zaawansowane - naciśnij Enter, by rozpocząć wyszukiwanie
-searchInProgress=Trwa wyszukiwanie... Proszę czekać.
+advancedSearchMode=Wyszukiwanie zaawansowane — naciśnij Enter aby rozpocząć wyszukiwanie.
+searchInProgress=Trwa wyszukiwanie — proszę czekać.
searchOperator.is=jest
searchOperator.isNot=nie jest
@@ -684,7 +684,7 @@ report.notes=Notatki:
report.tags=Etykiety:
annotations.confirmClose.title=Usuwanie adnotacji
-annotations.confirmClose.body=Czy na pewno chcesz usunąć tę adnotację?\n\nCała zawartość adnotacji zostanie utracona.
+annotations.confirmClose.body=Cała zawartość adnotacji zostanie utracona.
annotations.close.tooltip=Usuń adnotację
annotations.move.tooltip=Przenieś adnotację
annotations.collapse.tooltip=Zwiń adnotację
@@ -738,7 +738,7 @@ integration.missingItem.multiple=Element %1$S w tym cytowaniu już nie istnieje
integration.missingItem.description=Wybranie "Nie" usunie kody pól dla odnośników do tego elementu, zachowując tekst odnośników, ale usuwając element z bibliografii.
integration.removeCodesWarning=Usunięcie kodów pól spowoduje, że Zotero nie będzie w stanie zaktualizować odnośników oraz bibliografii w tym dokumencie. Czy jesteś pewien, że chcesz kontynuować?
integration.upgradeWarning=Twój dokument musi zostać na stałe zaktualizowany aby mógł współpracować z Zotero 2.0b7 lub nowszym. Zaleca się wykonanie kopii zapasowej. Czy chcesz kontynuować?
-integration.error.newerDocumentVersion=Your document was created with a newer version of Zotero (%1$S) than the currently installed version (%2$S). Please upgrade Zotero before editing this document.
+integration.error.newerDocumentVersion=Twój dokument został utworzony z użyciem nowszej wersji Zotero (%1$S) niż obecnie zainstalowana wersja (%2$S). Proszę uaktualnij Zotero przed edycją tego dokumentu.
integration.corruptField=Kod pola Zotero odpowiadający temu odnośnikowi, dzięki któremu Zotero jest w stanie powiązać ten odnośnik z pozycją w bibliotece, został uszkodzony. Czy chcesz ponownie wybrać element?
integration.corruptField.description=Wybranie "Nie" usunie kody pól dla odnośników do tego elementu, zachowując tekst odnośników, ale potencjalnie usuwając element z bibliografii.
integration.corruptBibliography=Kod pola Zotero dla bibliografii jest uszkodzony. Czy chcesz usunąć ten kod pola i wygenerować nową bibliografię?
@@ -770,33 +770,33 @@ sync.removeGroupsAndSync=Usuń grupy i synchronizuj
sync.localObject=Obiekt lokalny
sync.remoteObject=Obiekt zdalny
sync.mergedObject=Złączony obiekt
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Użyj wersji lokalnych dla wszystkich pozostałych konfliktów.
+sync.merge.resolveAllRemote=Użyj wersji zdalnych dla wszystkich pozostałych konfliktów.
sync.error.usernameNotSet=Nie podano nazwy użytkownika
sync.error.usernameNotSet.text=W celu synchronizacji z serwerem Zotero musisz podać w ustawieniach Zotero swoją nazwę użytkownika i hasło używane w serwisie zotero.org.
sync.error.passwordNotSet=Nie podano hasła
sync.error.invalidLogin=Błędna nazwa użytkownika lub hasło
-sync.error.invalidLogin.text=Serwer synchronizacji Zotero nie zaakceptował twojej nazwy użytkownika i hasła.\n\nProszę sprawdź, czy twoje informacje logowania zostały poprawnie wpisane w ustawieniach synchronizacji Zotero.
+sync.error.invalidLogin.text=Serwer synchronizacji Zotero nie zaakceptował twojej nazwy użytkownika i hasła.\n\nProszę sprawdź, czy twoje dane logowania zostały poprawnie wpisane w ustawieniach synchronizacji Zotero.
sync.error.enterPassword=Proszę podać hasło.
sync.error.loginManagerInaccessible=Zotero nie może uzyskać dostępu do twoich danych logowania.
sync.error.checkMasterPassword=Jeśli używasz hasła głównego w %S upewnij się, że zostało ono wprowadzone poprawnie.
-sync.error.corruptedLoginManager=Może to być także spowodowane uszkodzoną bazą danych haseł %1$S. Aby sprawdzić, zamknij %1$S, usuń plik signons.sqlite ze swojego katalogu profilu %1$S, a następnie ponownie wprowadź swoje dane logowania Zotero w panelu Synchronizacja w ustawieniach Zotero.
+sync.error.corruptedLoginManager=Może to być także spowodowane uszkodzoną bazą danych haseł %1$S. Aby to sprawdzić, zamknij %1$S, usuń plik signons.sqlite ze swojego katalogu profilu %1$S, a następnie wprowadź ponownie swoje dane logowania Zotero w panelu Synchronizacja w ustawieniach Zotero.
sync.error.loginManagerCorrupted1=Zotero nie może uzyskać dostępu do twoich danych logowania, prawdopodobnie z powodu uszkodzonej bazy danych haseł %S.
-sync.error.loginManagerCorrupted2=Close %1$S, remove signons.sqlite from your %2$S profile directory, and re-enter your Zotero login information in the Sync pane of the Zotero preferences.
+sync.error.loginManagerCorrupted2=Zamknij %1$S, usuń plik signons.sqlite z twojego katalogu profilu %2$S, a następnie wprowadź ponownie swoje dane logowania Zotero w panelu Synchronizacja w ustawieniach Zostero.
sync.error.syncInProgress=Synchronizacja jest aktualnie w trakcie.
sync.error.syncInProgress.wait=Poczekaj na zakończenie poprzedniej synchronizacji albo uruchom ponownie %S.
sync.error.writeAccessLost=Nie masz już uprawnień zapisu do grupy Zotero "%S", a więc dodane lub edytowane elementy nie mogą zostać zsynchronizowane z serwerem.
-sync.error.groupWillBeReset=Jeżeli będziesz kontynuować, twoja kopia grupy zostanie przywrócona do stanu na serwerze, a lokalne zmiany pozycji oraz plików zostaną usunięte.
+sync.error.groupWillBeReset=Jeżeli będziesz kontynuować, twoja kopia grupy zostanie przywrócona do stanu jak na serwerze, a lokalne zmiany elementówi oraz plików zostaną utracone.
sync.error.copyChangedItems=Jeżeli chcesz mieć możliwość skopiowania zmienionych elementów w inne miejsce lub chcesz poprosić administratora grupy o prawo do zapisu, anuluj teraz synchronizację.
sync.error.manualInterventionRequired=Automatyczna synchronizacja spowodowała konflikt, który wymaga ręcznej interwencji.
-sync.error.clickSyncIcon=Naciśnij ikonę synchronizacji aby zsynchronizować ręcznie..
+sync.error.clickSyncIcon=Naciśnij ikonę synchronizacji aby zsynchronizować ręcznie.
sync.error.invalidClock=Zegar systemowy jest ustawiony na nieprawidłowy czas. Aby zsynchronizować dane z serwerem Zotero należy skorygować ustawienie czasu.
sync.error.sslConnectionError=Błąd połączenia SSL
sync.error.checkConnection=Błąd połączenia z serwerem. Sprawdź swoje połączenie internetowe.
sync.error.emptyResponseServer=Pusta odpowiedź z serwera.
-sync.error.invalidCharsFilename=Nazwa pliku '%S' zawiera nieprawidłowe znaki.\n\nZmień nazwę pliku, a następnie spróbuj ponownie. Jeśli zmienisz nazwę pliku za pomocą systemu, będzie trzeba ponownie połączyć ją z elementem w Zotero.
+sync.error.invalidCharsFilename=Nazwa pliku "%S" zawiera nieprawidłowe znaki.\n\nZmień nazwę pliku, a następnie spróbuj ponownie. Jeśli zmienisz nazwę pliku za pomocą systemu, będzie trzeba ponownie połączyć ją z elementem w Zotero.
sync.lastSyncWithDifferentAccount=Ta baza danych Zotero była ostatnio synchronizowana z innego konta zotero.org (%1$S) niż obecnie używane (%2$S).
sync.localDataWillBeCombined=Jeśli będziesz kontynuować, lokalne dane Zotero zostaną połączone z danymi z konta "%S" przechowywanymi na serwerze.
@@ -805,13 +805,13 @@ sync.avoidCombiningData=Aby zapobiec połączeniu lub utracie danych, przywróć
sync.localGroupsWillBeRemoved2=Jeśli będziesz kontynuować, grupy lokalne, również te ze zmienionymi elementami, będą usunięte i zastąpione grupami z konta "%1$S".\n\nAby zapobiec utracie zmian w grupach, upewnij się że dokonana została najpierw synchronizacja z kontem "%2$S" zanim dokonasz synchronizacji z kontem "%1$S".
sync.conflict.autoChange.alert=Od czasu ostatniej synchronizacji jeden lub więcej lokalnie usuniętych elementów "%S" Zotero zostało zdalnie zmodyfikowanych.
-sync.conflict.autoChange.log=A Zotero %S has changed both locally and remotely since the last sync:
+sync.conflict.autoChange.log=Od czasu ostatniej synchronizacji Zotero %S został zmieniony zarówno lokalnie, jak i zdalnie:
sync.conflict.remoteVersionsKept=Zachowano wersje zdalne.
sync.conflict.remoteVersionKept=Zachowano wersję zdalną.
sync.conflict.localVersionsKept=Zachowano wersje lokalne.
sync.conflict.localVersionKept=Zachowano wersję lokalną.
sync.conflict.recentVersionsKept=Zachowano najnowsze wersje.
-sync.conflict.recentVersionKept=Zachowano najnowszą wersję '%S'.
+sync.conflict.recentVersionKept=Zachowano najnowszą wersję "%S".
sync.conflict.viewErrorConsole=Zobacz konsolę błędów %S, aby przejżeć pełną listę zmian.
sync.conflict.localVersion=Lokalna wersja: %S
sync.conflict.remoteVersion=Zdalna wersja: %S
@@ -820,8 +820,8 @@ sync.conflict.collectionItemMerge.alert=Od czasu ostatniej synchronizacji jeden
sync.conflict.collectionItemMerge.log=Od czasu ostatniej synchronizacji elementy w kolekcji "%S" zostały dodane i/lub usunięte na różnych komputerach. Następujące elementy zostały dodane do kolekcji:
sync.conflict.tagItemMerge.alert=Od czasu ostatniej synchronizacji jeden lub więcej znaczników zostało dodanych i/lub usuniętych z elementów na różnych komputerach.
sync.conflict.tagItemMerge.log=Od czasu ostatniej synchronizacji znacznik "%S" został dodany i/lub usunięty z elementów na różnych komputerach.
-sync.conflict.tag.addedToRemote=It has been added to the following remote items:
-sync.conflict.tag.addedToLocal=It has been added to the following local items:
+sync.conflict.tag.addedToRemote=Dodano do następujących elementów zdalnych:
+sync.conflict.tag.addedToLocal=Dodano do następujących elementów lokalnych:
sync.conflict.fileChanged=Następujący plik został zmieniony w różnych miejscach.
sync.conflict.itemChanged=Następujący element został zmieniony w różnych miejscach.
@@ -834,7 +834,7 @@ sync.status.loggingIn=Logowanie do serwera synchronizacji
sync.status.gettingUpdatedData=Odbieranie zaktualizowanych danych z serwera synchronizacji
sync.status.processingUpdatedData=Przetwarzanie zaktualizowanych danych
sync.status.uploadingData=Wysyłanie danych na serwer synchronizacji
-sync.status.uploadAccepted=Wysyłanie zaakceptowane \— oczekiwanie na serwer synchronizacji
+sync.status.uploadAccepted=Wysyłanie zaakceptowane — oczekiwanie na serwer synchronizacji
sync.status.syncingFiles=Synchronizowanie plików
sync.fulltext.upgradePrompt.title=Nowe: synchronizacja zawartości pełnotekstowej
@@ -855,23 +855,23 @@ sync.storage.serverConfigurationVerified=Konfiguracja serwera zweryfikowana.
sync.storage.fileSyncSetUp=Ustawienia synchronizacji plików zdefiniowano pomyślnie.
sync.storage.openAccountSettings=Otwórz ustawienia konta
-sync.storage.error.default=A file sync error occurred. Please try syncing again.\n\nIf you receive this message repeatedly, restart %S and/or your computer and try again. If you continue to receive the message, submit an error report and post the Report ID to a new thread in the Zotero Forums.
-sync.storage.error.defaultRestart=A file sync error occurred. Please restart %S and/or your computer and try syncing again.\n\nIf you receive this message repeatedly, submit an error report and post the Report ID to a new thread in the Zotero Forums.
+sync.storage.error.default=Wystąpił błąd synchronizacji plików. Proszę spróbować synchronizacji ponownie.\n\nJeśli ten błąd się powtarza, uruchom ponownie %S i/lub komputer i spróbuj ponownie. Jeśli ten błąd nadal się powtarza, wyślij raport błędu z podaniem identyfikatora błędu (ID) do nowego wątku na forum Zotero.
+sync.storage.error.defaultRestart=Wystąpił błąd synchronizacji plików. Proszę spróbować synchronizacji ponownie.\n\nJeśli ten błąd się powtarza, wyślij raport błędu z podaniem identyfikatora błędu (Report ID) do nowego wątku na forum Zotero.
sync.storage.error.serverCouldNotBeReached=Nie można osiągnąć serwera %S.
sync.storage.error.permissionDeniedAtAddress=Nie masz uprawnień do utworzenia katalogu Zotero w adresie:
sync.storage.error.checkFileSyncSettings=Proszę sprawdzić swoje ustawienia synchronizacji plików lub skontaktować się ze swoim administratorem serwera.
sync.storage.error.verificationFailed=Weryfikacja %S nie powiodła się. Sprawdź swoje ustawienia synchronizacji plików w panelu Synchronizacja w ustawieniach Zotero.
-sync.storage.error.fileNotCreated=Nie można utworzyć pliku '%S' w katalogu danych Zotero.
+sync.storage.error.fileNotCreated=Nie można utworzyć pliku "%S" w katalogu danych Zotero.
sync.storage.error.encryptedFilenames=Błąd tworzenia pliku "%S".\n\nZobacz http://www.zotero.org/support/kb/encrypted_filenames, aby uzyskać więcej informacji.
-sync.storage.error.fileEditingAccessLost=Nie masz już prawa modyfikowania plików w grupie '%S', w związku z czym pliki które dodałeś lub zmieniłeś nie mogą być zsynchronizowane z serwerem.
+sync.storage.error.fileEditingAccessLost=Nie masz już prawa modyfikowania plików w grupie "%S", w związku z czym pliki które dodałeś lub zmieniłeś nie mogą być zsynchronizowane z serwerem.
sync.storage.error.copyChangedItems=Jeśli chcesz mieć możliwość skopiowania zmienionych elementów i plików w inne miejsce, anuluj teraz synchronizację.
sync.storage.error.fileUploadFailed=Wysyłanie pliku nie powiodło się.
sync.storage.error.directoryNotFound=Nie znaleziono katalogu
sync.storage.error.doesNotExist=%S nie istnieje.
sync.storage.error.createNow=Czy chcesz go teraz utworzyć?
-sync.storage.error.webdav.default=A WebDAV file sync error occurred. Please try syncing again.\n\nIf you receive this message repeatedly, check your WebDAV server settings in the Sync pane of the Zotero preferences.
-sync.storage.error.webdav.defaultRestart=A WebDAV file sync error occurred. Please restart %S and try syncing again.\n\nIf you receive this message repeatedly, check your WebDAV server settings in the Sync pane of the Zotero preferences.
+sync.storage.error.webdav.default=Wystąpił błąd podczas synchronizacji plików z użyciem WebDAV. Proszę spróbować synchronizacji ponownie.\n\nJeśli ten błąd się powtarza, sprawdź swoje ustawienia serwera WebDAV w panelu Synchronizacja w ustawieniach Zotero.
+sync.storage.error.webdav.defaultRestart=Wystąpił błąd podczas synchronizacji plików z użyciem WebDAV. Proszę uruchomić ponownie %S i spróbować synchronizacji jeszcze raz.\n\nJeśli ten błąd się powtarza, sprawdź swoje ustawienia serwera WebDAV w panelu Synchronizacja w ustawieniach Zotero.
sync.storage.error.webdav.enterURL=Proszę wprowadzić URL WebDAV.
sync.storage.error.webdav.invalidURL=%S nie jest poprawnym URL WebDAV.
sync.storage.error.webdav.invalidLogin=Serwer WebDAV nie zaakceptował podanych przez ciebie nazwy użytkownika i hasła.
@@ -880,20 +880,20 @@ sync.storage.error.webdav.insufficientSpace=Przesyłanie plików nie powiodło s
sync.storage.error.webdav.sslCertificateError=Błąd certyfikatu SSL podczas łączenia z %S.
sync.storage.error.webdav.sslConnectionError=Błąd połączenia SSL podczas łączenia z %S.
sync.storage.error.webdav.loadURLForMoreInfo=Wczytaj swój URL WebDAV w przeglądarce aby uzyskać więcej informacji.
-sync.storage.error.webdav.seeCertOverrideDocumentation=Aby uzyskać więcej informacji zobacz dokumentację dotyczącą wymuszenia certyfikatu
+sync.storage.error.webdav.seeCertOverrideDocumentation=Aby uzyskać więcej informacji zobacz dokumentację dotyczącą wymuszenia certyfikatu.
sync.storage.error.webdav.loadURL=Wczytaj URL WebDAV
sync.storage.error.webdav.fileMissingAfterUpload=A potential problem was found with your WebDAV server.\n\nAn uploaded file was not immediately available for download. There may be a short delay between when you upload files and when they become available, particularly if you are using a cloud storage service.\n\nIf Zotero file syncing appears to work normally, you can ignore this message. If you have trouble, please post to the Zotero Forums.
sync.storage.error.webdav.nonexistentFileNotMissing=Your WebDAV server is claiming that a nonexistent file exists. Contact your WebDAV server administrator for assistance.
sync.storage.error.webdav.serverConfig.title=Błąd konfiguracji serwera WebDAV
sync.storage.error.webdav.serverConfig=Twój serwer WebDAV zwrócił błąd wewnętrzny.
-sync.storage.error.zfs.restart=Wystąpił błąd synchronizacji. Proszę uruchomić ponownie %S i/lub komputer i spróbować synchronizacji ponownie.\n\nJeśli błąd się powtarza, być może masz problem z twoim komputerem lub siecią: oprogramowaniem zabezpieczającym, serwerem proxy, VPN itp. Spróbuj wyłączyć aktywne oprogramowanie zabezpieczające/firewall. Jeśli używasz laptopa, spróbuj synchronizacji z innej sieci.
+sync.storage.error.zfs.restart=Wystąpił błąd synchronizacji plików. Proszę uruchomić ponownie %S i/lub komputer i spróbować synchronizacji ponownie.\n\nJeśli błąd się powtarza, być może masz problem z twoim komputerem lub siecią: oprogramowaniem zabezpieczającym, serwerem proxy, VPN itp. Spróbuj wyłączyć aktywne oprogramowanie zabezpieczające lub firewall. Jeśli używasz laptopa, spróbuj synchronizacji z innej sieci.
sync.storage.error.zfs.tooManyQueuedUploads=Masz zbyt dużo wysyłań w kolejce. Proszę spróbuj ponownie za %S minut.
sync.storage.error.zfs.personalQuotaReached1=Twój limit przechowywania plików w Zotero został osiągnięty. Niektóre pliki nie zostały przesłane. Pozostałe dane Zotero zostaną zsynchronizowane z serwerem.
sync.storage.error.zfs.personalQuotaReached2=Dla dodatkowych opcji przechowywania plików sprawdź swoje ustawienia konta na zotero.org.
-sync.storage.error.zfs.groupQuotaReached1=Limit przechowywania plików dla grupy '%S' został osiągnięty. Niektóre pliki nie zostały przesłane. Pozostałe dane Zotero zostaną zsynchronizowane z serwerem.
+sync.storage.error.zfs.groupQuotaReached1=Limit przechowywania plików dla grupy "%S" został osiągnięty. Niektóre pliki nie zostały przesłane. Pozostałe dane Zotero zostaną zsynchronizowane z serwerem.
sync.storage.error.zfs.groupQuotaReached2=Właściciel grupy może zwiększyć pojemność przechowywania dla grupy w sekcji ustawień na zotero.org.
-sync.storage.error.zfs.fileWouldExceedQuota=Plik '%S' przekroczy rozmiar dostępny dla ciebie do przechowywania plików Zotero (Zotero File Storage)
+sync.storage.error.zfs.fileWouldExceedQuota=Plik "%S" przekroczy rozmiar dostępnej dla ciebie przestrzeni do przechowywania plików Zotero
sync.longTagFixer.saveTag=Zapisz etykietę
sync.longTagFixer.saveTags=Zapisz etykiety
@@ -936,7 +936,7 @@ rtfScan.saveTitle=Wybierz lokalizację, gdzie zapisać sformatowany plik
rtfScan.scannedFileSuffix=(Przeskanowano)
-file.accessError.theFile=Plik '%S'
+file.accessError.theFile=Plik "%S"
file.accessError.aFile=Plik
file.accessError.cannotBe=nie może zostać
file.accessError.created=utworzony
@@ -966,13 +966,13 @@ locate.internalViewer.tooltip=Otwórz plik w tej aplikacji
locate.showFile.label=Pokaż plik
locate.showFile.tooltip=Otwórz katalog w którym znajduje się ten plik
locate.libraryLookup.label=Wyszukiwanie
-locate.libraryLookup.tooltip=Wyszukaj ten element używając wybranego resolwera OpenURL
+locate.libraryLookup.tooltip=Wyszukaj ten element używając wybranej usługi OpenURL
locate.manageLocateEngines=Zarządzanie silnikami wyszukiwania...
standalone.corruptInstallation=Twoja instalacja samodzielnego programu Zotero jest prawdopodobnie uszkodzona z powodu nieprawidłowej automatycznej aktualizacji. Mimo tego Zotero może działać, jednak aby uniknąć potencjalnych błędów, proszę jak najszybciej pobrać najnowszą wersję samodzielnego programu Zotero ze strony http://zotero.org/support/standalone.
-standalone.addonInstallationFailed.title=Instalacja dodatku nie powiodła się.
+standalone.addonInstallationFailed.title=Instalacja dodatku nie powiodła się
standalone.addonInstallationFailed.body=Nie można zainstalować dodatku "%S". Może on być niezgodny z tą wersją samodzielnego programu Zotero.
-standalone.rootWarning=You appear to be running Zotero Standalone as root. This is insecure and may prevent Zotero from functioning when launched from your user account.\n\nIf you wish to install an automatic update, modify the Zotero program directory to be writeable by your user account.
+standalone.rootWarning=Wygląda na to, że Zotero został uruchomiony z konta administratora systemu. Jest to niebezpieczne i może spowodować nieprawidłowe funkcjonowanie Zotero w przyszłości, jeśli zostanie uruchomiony z twojego konta użytkownika.\n\nJeśli chcesz zainstalować automatyczne uaktualnienie, zmodyfikuj uprawnienia katalogu z programem Zotero tak, aby mieć prawo zapisu w tym katalogu ze swojego konta użytkownika.
standalone.rootWarning.exit=Wyjście
standalone.rootWarning.continue=Kontynuuj
standalone.updateMessage=Dostępna jest zalecana aktualizacja, ale nie masz uprawnień do jej zainstalowania. Aby dokonać automatycznej aktualizacji, zmodyfikuj uprawnienia katalogu, w którym znajduje się program Zotero, tak aby mieć w nim prawo zapisu.
diff --git a/chrome/locale/pt-BR/zotero/preferences.dtd b/chrome/locale/pt-BR/zotero/preferences.dtd
index c712127739..19bebf726b 100644
--- a/chrome/locale/pt-BR/zotero/preferences.dtd
+++ b/chrome/locale/pt-BR/zotero/preferences.dtd
@@ -160,7 +160,7 @@
-
+
@@ -201,6 +201,6 @@
-
-
+
+
diff --git a/chrome/locale/pt-BR/zotero/zotero.dtd b/chrome/locale/pt-BR/zotero/zotero.dtd
index ed51d9793f..8e4e936ae4 100644
--- a/chrome/locale/pt-BR/zotero/zotero.dtd
+++ b/chrome/locale/pt-BR/zotero/zotero.dtd
@@ -27,7 +27,7 @@
-
+
@@ -60,8 +60,8 @@
-
-
+
+
@@ -86,19 +86,19 @@
-
+
-
-
-
+
+
+
-
+
-
-
+
+
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/pt-BR/zotero/zotero.properties b/chrome/locale/pt-BR/zotero/zotero.properties
index 356a132e2b..a00d9e728a 100644
--- a/chrome/locale/pt-BR/zotero/zotero.properties
+++ b/chrome/locale/pt-BR/zotero/zotero.properties
@@ -42,7 +42,7 @@ general.create=Criar
general.delete=Remover
general.moreInformation=Mais informação
general.seeForMoreInformation=Ver %S para mais informações.
-general.open=Open %S
+general.open=Abrir %S
general.enable=Habilitar
general.disable=Desabilitar
general.remove=Remover
@@ -162,7 +162,7 @@ pane.collections.newSavedSeach=Nova pesquisa salva
pane.collections.savedSearchName=Digite um nome para essa pesquisa salva:
pane.collections.rename=Renomear coleção:
pane.collections.library=Minha biblioteca
-pane.collections.groupLibraries=Agrupar bibliotecas
+pane.collections.groupLibraries=Bibliotecas do grupo
pane.collections.trash=Lixeira
pane.collections.untitled=Sem título
pane.collections.unfiled=Documentos sem coleção
@@ -185,9 +185,9 @@ pane.tagSelector.rename.title=Renomear marcador.
pane.tagSelector.rename.message=Por favor, digite um novo nome para este marcador.\n\nO marcador será alterado em todos os itens associados.
pane.tagSelector.delete.title=Excluir marcador
pane.tagSelector.delete.message=Tem certeza de que deseja excluir este marcador?\n\nO marcador será removido de todos os itens.
-pane.tagSelector.numSelected.none=0 marcadores selecionados.
+pane.tagSelector.numSelected.none=Nenhuma etiqueta selecionada
pane.tagSelector.numSelected.singular=%S marcador selecionado
-pane.tagSelector.numSelected.plural=%S marcadores selecionados
+pane.tagSelector.numSelected.plural=%S etiquetas selecionadas
pane.tagSelector.maxColoredTags=Apenas %S etiquetas em cada biblioteca podem ter cores designada.
tagColorChooser.numberKeyInstructions=Você pode adicionar essa etiqueta para selecionar itens pressionando a tecla $NUMBER do teclado.
@@ -196,19 +196,19 @@ tagColorChooser.maxTags=Até %S etiquetas em cada biblioteca podem ter cores des
pane.items.loading=Carregando lista de itens...
pane.items.columnChooser.moreColumns=Mais Colunas
pane.items.columnChooser.secondarySort=Classificação secundária (%S)
-pane.items.attach.link.uri.unrecognized=Zotero did not recognize the URI you entered. Please check the address and try again.
-pane.items.attach.link.uri.file=To attach a link to a file, please use “%S”.
+pane.items.attach.link.uri.unrecognized=O Zotero não reconheceu a URI que você digitou. Por favor, verifique o endereço e tente novamente.
+pane.items.attach.link.uri.file=Para anexar um link a um arquivo, por favor use “%S”.
pane.items.trash.title=Mover para a Lixeira
pane.items.trash=Tem certeza de que deseja mover o item selecionado para a Lixeira?
pane.items.trash.multiple=Tem certeza de que deseja mover os itens selecionados para a Lixeira?
pane.items.delete.title=Excluir
pane.items.delete=Tem certeza de que deseja excluir o item selecionado?
pane.items.delete.multiple=Tem certeja de que deseja excluir os itens selecionados?
-pane.items.remove.title=Remove from Collection
-pane.items.remove=Are you sure you want to remove the selected item from this collection?
-pane.items.remove.multiple=Are you sure you want to remove the selected items from this collection?
-pane.items.menu.remove=Remove Item from Collection…
-pane.items.menu.remove.multiple=Remove Items from Collection…
+pane.items.remove.title=Remover da coleção
+pane.items.remove=Tem certeza que deseja remover o item selecionado dessa coleção?
+pane.items.remove.multiple=Você está certo de que deseja remover os itens selecionados dessa coleção?
+pane.items.menu.remove=Remover item da coleção...
+pane.items.menu.remove.multiple=Remover itens da coleção...
pane.items.menu.moveToTrash=Mover Item para a lixeira...
pane.items.menu.moveToTrash.multiple=Mover itens para a lixeira
pane.items.menu.export=Exportar item selecionado...
@@ -225,7 +225,7 @@ pane.items.menu.createParent=Criar item no nível acima do item selecionado
pane.items.menu.createParent.multiple=Criar itens no nível acima dos itens selecionados
pane.items.menu.renameAttachments=Renomear arquivo a partir dos metadados do item no nível acima
pane.items.menu.renameAttachments.multiple=Renomear arquivos a partir dos metadados do item no nível acima
-pane.items.showItemInLibrary=Show Item in Library
+pane.items.showItemInLibrary=Exibir item na biblioteca
pane.items.letter.oneParticipant=Carta para %S
pane.items.letter.twoParticipants=Carta para %S e %S
@@ -276,9 +276,9 @@ pane.item.attachments.PDF.installTools.title=PDF Tools não está instalado
pane.item.attachments.PDF.installTools.text=Para utilizar esse recurso você deve primeiro instalar as ferramentas PDF no painel de Busca das preferências do Zotero.
pane.item.attachments.filename=Nome do arquivo
pane.item.noteEditor.clickHere=clique aqui
-pane.item.tags.count.zero=%S marcadores:
+pane.item.tags.count.zero=%S etiquetas:
pane.item.tags.count.singular=%S marcador:
-pane.item.tags.count.plural=%S marcadores:
+pane.item.tags.count.plural=%S etiquetas:
pane.item.tags.icon.user=Marcador do usuário
pane.item.tags.icon.automatic=Marcador automático
pane.item.related.count.zero=%S relacionado:
@@ -331,7 +331,7 @@ itemFields.dateAdded=Data de adição
itemFields.dateModified=Data de modificação
itemFields.source=Fonte
itemFields.notes=Notas
-itemFields.tags=Marcadores
+itemFields.tags=Etiquetas
itemFields.attachments=Anexos
itemFields.related=Relatar
itemFields.url=URL
@@ -566,13 +566,13 @@ zotero.preferences.export.quickCopy.exportFormats=Formatos de exportação
zotero.preferences.export.quickCopy.instructions=A cópia rápida permite copiar referências selecionadas para a área de transferência ao apertar uma tecla de atalho (%S) ou ao arrastar itens para uma caixa de texto em uma página web.
zotero.preferences.export.quickCopy.citationInstructions=Para estilos bibliográficos, você pode copiar citações ou notas de rodapé apertando %S ou arrastando os ítens segurando a tecla SHIFT.
-zotero.preferences.wordProcessors.installationSuccess=Installation was successful.
-zotero.preferences.wordProcessors.installationError=Installation could not be completed because an error occurred. Please ensure that %1$S is closed, and then restart %2$S.
-zotero.preferences.wordProcessors.installed=The %S add-in is currently installed.
-zotero.preferences.wordProcessors.notInstalled=The %S add-in is not currently installed.
-zotero.preferences.wordProcessors.install=Install %S Add-in
-zotero.preferences.wordProcessors.reinstall=Reinstall %S Add-in
-zotero.preferences.wordProcessors.installing=Installing %S…
+zotero.preferences.wordProcessors.installationSuccess=A instalação foi concluída com sucesso.
+zotero.preferences.wordProcessors.installationError=Um erro não permitiu que a instalação fosse completada. Por favor, certifique-se que %1$S está fechado, e então reinicie %2$S.
+zotero.preferences.wordProcessors.installed=O suplemento %S está instalado.
+zotero.preferences.wordProcessors.notInstalled=O suplemento %S não está instalado.
+zotero.preferences.wordProcessors.install=Instalar o suplemento $S
+zotero.preferences.wordProcessors.reinstall=Reinstalar o suplemento $S
+zotero.preferences.wordProcessors.installing=Instalando %S...
zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S is incompatible with versions of %3$S before %4$S. Please remove %3$S, or download the latest version from %5$S.
zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S requires %3$S %4$S or later to run. Please download the latest version of %3$S from %5$S.
@@ -681,7 +681,7 @@ citation.notes=Notas
report.title.default=Relatório Zotero
report.parentItem=Item no nível acima:
report.notes=Notas:
-report.tags=Marcadores
+report.tags=Etiquetas:
annotations.confirmClose.title=Tem certeza de que deseja fechar esta anotação?
annotations.confirmClose.body=Todo o texto será perdido.
@@ -738,7 +738,7 @@ integration.missingItem.multiple=O item %1$S nesta citação não existe mais em
integration.missingItem.description=Clicar em "Não" excluirá os códigos do campo de citações que contém este item, preservando o texto da citação, mas excluindo-a de sua bibliografia.
integration.removeCodesWarning=A remoção dos códigos de campo impedirá que Zotero atualize citações e bibliografias neste documento. Tem certeza de que deseja continuar?
integration.upgradeWarning=Seu documento deve ser atualizado permanentemente para trabalhar com a versão Zotero 2.0b7 ou posterior. É recomendado que você faça uma cópia de segurança antes de prosseguir. Tem certeza de que deseja continuar?
-integration.error.newerDocumentVersion=Your document was created with a newer version of Zotero (%1$S) than the currently installed version (%2$S). Please upgrade Zotero before editing this document.
+integration.error.newerDocumentVersion=Esse documento foi criado em uma versão mais recente do Zotero (%1$S) do que a atualmente instalada (%2$S). Por favor, atualize o Zotero antes de editar esse documento.
integration.corruptField=O código do campo Zotero correspondente a esta citação, que diz a Zotero qual item em sua bibliografia esta citação representa, foi corrompido. Gostaria de selecionar este item novamente?
integration.corruptField.description=Clicar em "Não" excluirá os códigos do campo de citações que contém este item, preservando o texto da citação mas potencialmente excluindo-a de sua bibliografia.
integration.corruptBibliography=O código de campo Zotero para sua bibliografia foi corrompido. Zotero deve reconfigurar este campo e gerar uma nova bibliografia?
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Remover grupos e sincronização
sync.localObject=Objeto local
sync.remoteObject=Objeto remoto
sync.mergedObject=Objeto mesclado
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Use a versão local para todos os demais conflitos.
+sync.merge.resolveAllRemote=Use a versão remota para todos os demais conflitos.
sync.error.usernameNotSet=Nome de usuário não configurado
@@ -896,7 +896,7 @@ sync.storage.error.zfs.groupQuotaReached2=O dono do grupo pode aumentar a capaci
sync.storage.error.zfs.fileWouldExceedQuota=O arquivo '%S' excederia seu espaço de armazenamento no Zotero
sync.longTagFixer.saveTag=Salvar marcador
-sync.longTagFixer.saveTags=Salvar marcadores
+sync.longTagFixer.saveTags=Salvar etiquetas
sync.longTagFixer.deleteTag=Excluir marcador
proxies.multiSite=Multi-site
@@ -988,11 +988,11 @@ firstRunGuidance.quickFormatMac=Digite um título ou autor para procurar por uma
firstRunGuidance.toolbarButton.new=Clique aqui para abrir o Zotero, ou utilize o atalho %S em seu teclado.
firstRunGuidance.toolbarButton.upgrade=O ícone do Zotero pode agora ser encontrado na barra de ferramentas do Firefox. Clique no ícone para abrir o Zotero, ou utilize o atalho %S em seu teclado.
-styles.bibliography=Bibliography
-styles.editor.save=Save Citation Style
-styles.editor.warning.noItems=No items selected in Zotero.
+styles.bibliography=Bibliografia
+styles.editor.save=Salvar o estilo de citação
+styles.editor.warning.noItems=Não foi selecionado nenhum item no Zotero.
styles.editor.warning.parseError=Error parsing style:
-styles.editor.warning.renderError=Error generating citations and bibliography:
-styles.editor.output.individualCitations=Individual Citations
-styles.editor.output.singleCitation=Single Citation (with position "first")
-styles.preview.instructions=Select one or more items in Zotero and click the "Refresh" button to see how these items are rendered by the installed CSL citation styles.
+styles.editor.warning.renderError=Ocorreu um erro na geração de citações e bibliografia:
+styles.editor.output.individualCitations=Citações individuais
+styles.editor.output.singleCitation=Citação única (com a posição "primeira")
+styles.preview.instructions=Selecione um ou mais itens no Zotero e pressione o botão "Atualizar" para ver como esses itens são carregados pelos estilos de citação CSL instalados.
diff --git a/chrome/locale/pt-PT/zotero/zotero.dtd b/chrome/locale/pt-PT/zotero/zotero.dtd
index 8b27a19569..eb44a8e98c 100644
--- a/chrome/locale/pt-PT/zotero/zotero.dtd
+++ b/chrome/locale/pt-PT/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/ro-RO/zotero/zotero.dtd b/chrome/locale/ro-RO/zotero/zotero.dtd
index 62fdd50444..9c7bc641d2 100644
--- a/chrome/locale/ro-RO/zotero/zotero.dtd
+++ b/chrome/locale/ro-RO/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/ru-RU/zotero/zotero.dtd b/chrome/locale/ru-RU/zotero/zotero.dtd
index 522121c549..af5994e877 100644
--- a/chrome/locale/ru-RU/zotero/zotero.dtd
+++ b/chrome/locale/ru-RU/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/sk-SK/zotero/zotero.dtd b/chrome/locale/sk-SK/zotero/zotero.dtd
index e3019f214b..e4f1233e88 100644
--- a/chrome/locale/sk-SK/zotero/zotero.dtd
+++ b/chrome/locale/sk-SK/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/sk-SK/zotero/zotero.properties b/chrome/locale/sk-SK/zotero/zotero.properties
index 480a019c88..c294582655 100644
--- a/chrome/locale/sk-SK/zotero/zotero.properties
+++ b/chrome/locale/sk-SK/zotero/zotero.properties
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Odstrániť skupiny a synchronizovať
sync.localObject=Miestny objekt
sync.remoteObject=Vzdialený objekt
sync.mergedObject=Zlúčený objekt
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Použite lokálnu verziu pre všetky ostatné konflikty
+sync.merge.resolveAllRemote=Použite vzdialenú verziu pre všetky ostatné konflikty
sync.error.usernameNotSet=Nie je nastavené meno používateľa
diff --git a/chrome/locale/sl-SI/zotero/zotero.dtd b/chrome/locale/sl-SI/zotero/zotero.dtd
index 5995653766..e0232efbea 100644
--- a/chrome/locale/sl-SI/zotero/zotero.dtd
+++ b/chrome/locale/sl-SI/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/sl-SI/zotero/zotero.properties b/chrome/locale/sl-SI/zotero/zotero.properties
index 284c723515..5332b9d8a0 100644
--- a/chrome/locale/sl-SI/zotero/zotero.properties
+++ b/chrome/locale/sl-SI/zotero/zotero.properties
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Odstrani skupine in usklajevanje
sync.localObject=Krajevni predmet
sync.remoteObject=Oddaljeni predmet
sync.mergedObject=Spojeni predmet
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Uporabi krajevno različico za vse preostale spore
+sync.merge.resolveAllRemote=Uporabi oddaljeno različico za vse preostale spore
sync.error.usernameNotSet=Uporabniško ime ni določeno
diff --git a/chrome/locale/sr-RS/zotero/zotero.dtd b/chrome/locale/sr-RS/zotero/zotero.dtd
index 88a3971677..c297021180 100644
--- a/chrome/locale/sr-RS/zotero/zotero.dtd
+++ b/chrome/locale/sr-RS/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/sv-SE/zotero/zotero.dtd b/chrome/locale/sv-SE/zotero/zotero.dtd
index 193b8751de..e64dbbc301 100644
--- a/chrome/locale/sv-SE/zotero/zotero.dtd
+++ b/chrome/locale/sv-SE/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/sv-SE/zotero/zotero.properties b/chrome/locale/sv-SE/zotero/zotero.properties
index 015a16c87b..e7c3ec9f8d 100644
--- a/chrome/locale/sv-SE/zotero/zotero.properties
+++ b/chrome/locale/sv-SE/zotero/zotero.properties
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Ta bort grupp och synkronisering
sync.localObject=Lokalt objekt
sync.remoteObject=Fjärrobjekt
sync.mergedObject=Ihopsatt objekt
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Använd den lokala versionen för alla kvarvarande konflikter
+sync.merge.resolveAllRemote=Använd fjärrversionen för alla kvarvarande konflikter
sync.error.usernameNotSet=Användarnamn är inte valt
diff --git a/chrome/locale/th-TH/zotero/zotero.dtd b/chrome/locale/th-TH/zotero/zotero.dtd
index d3f8663c43..76146a0841 100644
--- a/chrome/locale/th-TH/zotero/zotero.dtd
+++ b/chrome/locale/th-TH/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/tr-TR/zotero/zotero.dtd b/chrome/locale/tr-TR/zotero/zotero.dtd
index 3d11fe53d2..674c27f91e 100644
--- a/chrome/locale/tr-TR/zotero/zotero.dtd
+++ b/chrome/locale/tr-TR/zotero/zotero.dtd
@@ -92,8 +92,8 @@
-
-
+
+
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/tr-TR/zotero/zotero.properties b/chrome/locale/tr-TR/zotero/zotero.properties
index 644e8d8e48..66169ccfc6 100644
--- a/chrome/locale/tr-TR/zotero/zotero.properties
+++ b/chrome/locale/tr-TR/zotero/zotero.properties
@@ -339,7 +339,7 @@ itemFields.rights=Telif
itemFields.series=Dizi
itemFields.volume=Cilt
itemFields.issue=Sayı
-itemFields.edition=Edisyon
+itemFields.edition=Baskı
itemFields.place=Yayın Yeri
itemFields.publisher=Yayıncı
itemFields.pages=Sayfa
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=Grubu Kaldır ve Eşitle
sync.localObject=Yerel Nesne
sync.remoteObject=Uzak Nesne
sync.mergedObject=Nesneyi Birleştir
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=Kalan tüm uyuşmazlıklar için yerel versiyonu kullan
+sync.merge.resolveAllRemote=Kalan tüm uyuşmazlıklar için uzaktaki versiyonu kullan
sync.error.usernameNotSet=Kullanıcı adı yok
@@ -806,15 +806,15 @@ sync.localGroupsWillBeRemoved2=Devam ederseniz, yerel gruplar, tüm değiştiril
sync.conflict.autoChange.alert=Son eşitlemeden beri, bir ya da birden çok, yerel olarak silinmiş Zotero %S'i uzaktan değiştirilmiş.
sync.conflict.autoChange.log=Bir Zotero %S'i son eşitlemeden beri hem yerel olarak hem uzakta değiştirilmiş.
-sync.conflict.remoteVersionsKept=Uzaktaki sürümler tutuldu.
-sync.conflict.remoteVersionKept=Uzaktaki sürüm tutuldu.
-sync.conflict.localVersionsKept=Yerel sürümler tutuldu.
-sync.conflict.localVersionKept=Yerel sürüm tutuldu.
-sync.conflict.recentVersionsKept=En yeni olan sürümler tutuldu.
+sync.conflict.remoteVersionsKept=Uzaktaki versiyonlar tutuldu.
+sync.conflict.remoteVersionKept=Uzaktaki versiyon tutuldu.
+sync.conflict.localVersionsKept=Yerel versiyonlar tutuldu.
+sync.conflict.localVersionKept=Yerel versiyon tutuldu.
+sync.conflict.recentVersionsKept=En yeni olan versiyonlar tutuldu.
sync.conflict.recentVersionKept=En yeni olan sürüm, '%S', tutuldu.
sync.conflict.viewErrorConsole=Bu değişikliklerin hepsini görebilmek için %S Hata Konsoluna bakanız.
-sync.conflict.localVersion=Yerel sürüm: %S
-sync.conflict.remoteVersion=Uzaktaki sürüm: %S
+sync.conflict.localVersion=Yerel versiyon: %S
+sync.conflict.remoteVersion=Uzaktaki versiyon: %S
sync.conflict.deleted=[silindi]
sync.conflict.collectionItemMerge.alert=Son eşitlemeden beri, birden çok bilgisayarda aynı dermeye ait bir ya da birden çok Zotero eseri eklenmiş ya da kaldırılmış.
sync.conflict.collectionItemMerge.log=Son eşitlemeden beri, birden çok bilgisayarda '%S' dermesindeki Zotero eserleri eklenmiş ya da kaldırılmış. Aşağıdaki şu eserler dermeye eklenmiştir:
@@ -825,8 +825,8 @@ sync.conflict.tag.addedToLocal=Bu, aşağıdaki yerel eserlere eklenmiştir:
sync.conflict.fileChanged=Şu dosya birden çok yerde değiştirilmiştir.
sync.conflict.itemChanged=Şu eser birden çok yerde değiştirilmiştir.
-sync.conflict.chooseVersionToKeep=Tutmak istediğiniz sürümü seçin, ve %S'yi tıklayın.
-sync.conflict.chooseThisVersion=Bu sürümü seçin
+sync.conflict.chooseVersionToKeep=Tutmak istediğiniz versiyonu seçin, ve %S'yi tıklayın.
+sync.conflict.chooseThisVersion=Bu versiyonu seç
sync.status.notYetSynced=Henüz eşitlenmedi
sync.status.lastSync=Son eşitleme:
diff --git a/chrome/locale/uk-UA/zotero/zotero.dtd b/chrome/locale/uk-UA/zotero/zotero.dtd
index 520cca23dc..322493267a 100644
--- a/chrome/locale/uk-UA/zotero/zotero.dtd
+++ b/chrome/locale/uk-UA/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/vi-VN/zotero/zotero.dtd b/chrome/locale/vi-VN/zotero/zotero.dtd
index 802d33da1f..af9d69f1de 100644
--- a/chrome/locale/vi-VN/zotero/zotero.dtd
+++ b/chrome/locale/vi-VN/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/zh-CN/zotero/zotero.dtd b/chrome/locale/zh-CN/zotero/zotero.dtd
index 4a1d136655..01978d9c71 100644
--- a/chrome/locale/zh-CN/zotero/zotero.dtd
+++ b/chrome/locale/zh-CN/zotero/zotero.dtd
@@ -126,6 +126,8 @@
+
+
diff --git a/chrome/locale/zh-CN/zotero/zotero.properties b/chrome/locale/zh-CN/zotero/zotero.properties
index edda5fd319..73e24d4501 100644
--- a/chrome/locale/zh-CN/zotero/zotero.properties
+++ b/chrome/locale/zh-CN/zotero/zotero.properties
@@ -573,8 +573,8 @@ zotero.preferences.wordProcessors.notInstalled=加载项 %S 现在未安装。
zotero.preferences.wordProcessors.install=安装加载项 %S
zotero.preferences.wordProcessors.reinstall=重新安装加载项 %S
zotero.preferences.wordProcessors.installing=安装 %S…
-zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S is incompatible with versions of %3$S before %4$S. Please remove %3$S, or download the latest version from %5$S.
-zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S requires %3$S %4$S or later to run. Please download the latest version of %3$S from %5$S.
+zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S 与 %4$S 之前的 %3$S 不兼容。请移除 %3$S,或者从 %5$S 下载最新版本。
+zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S 需要 %3$S %4$S 或者更新的版本运行。请从 %5$S 下载最新版本的 %3$S。
zotero.preferences.styles.addStyle=添加样式
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=移除群组和同步
sync.localObject=本地对象
sync.remoteObject=远程对象
sync.mergedObject=合并的对象
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=剩余的冲突项都采用本地版本
+sync.merge.resolveAllRemote=剩余的冲突项都采用远程版本
sync.error.usernameNotSet=未设置用户名
diff --git a/chrome/locale/zh-TW/zotero/preferences.dtd b/chrome/locale/zh-TW/zotero/preferences.dtd
index 77894a811f..d5a4b53648 100644
--- a/chrome/locale/zh-TW/zotero/preferences.dtd
+++ b/chrome/locale/zh-TW/zotero/preferences.dtd
@@ -160,7 +160,7 @@
-
+
@@ -201,6 +201,6 @@
-
-
+
+
diff --git a/chrome/locale/zh-TW/zotero/zotero.dtd b/chrome/locale/zh-TW/zotero/zotero.dtd
index 002feac3ae..80dac955ff 100644
--- a/chrome/locale/zh-TW/zotero/zotero.dtd
+++ b/chrome/locale/zh-TW/zotero/zotero.dtd
@@ -6,8 +6,8 @@
-
-
+
+
@@ -125,7 +125,9 @@
-
+
+
+
@@ -287,6 +289,6 @@
-
-
-
+
+
+
diff --git a/chrome/locale/zh-TW/zotero/zotero.properties b/chrome/locale/zh-TW/zotero/zotero.properties
index 583cb0145d..7ee5bfc62b 100644
--- a/chrome/locale/zh-TW/zotero/zotero.properties
+++ b/chrome/locale/zh-TW/zotero/zotero.properties
@@ -42,7 +42,7 @@ general.create=建立
general.delete=刪除
general.moreInformation=更多資訊
general.seeForMoreInformation=更多資訊請看 %S。
-general.open=Open %S
+general.open=開啟 %S
general.enable=啟用
general.disable=停用
general.remove=移除
@@ -196,19 +196,19 @@ tagColorChooser.maxTags=每一文獻庫至多 %S 個標籤能被指定顏色。
pane.items.loading=正載入項目清單…
pane.items.columnChooser.moreColumns=更多直欄
pane.items.columnChooser.secondarySort=第二排序 (%S)
-pane.items.attach.link.uri.unrecognized=Zotero did not recognize the URI you entered. Please check the address and try again.
-pane.items.attach.link.uri.file=To attach a link to a file, please use “%S”.
+pane.items.attach.link.uri.unrecognized=Zotero無法辨識您所輸入的網址,請確認後重試。
+pane.items.attach.link.uri.file=若要附加連結至檔案中,請使用"%S"
pane.items.trash.title=移到垃圾筒
pane.items.trash=確定要將所選項目移到垃圾筒?
pane.items.trash.multiple=確定要將所選眾項目移到垃圾筒?
pane.items.delete.title=刪除
pane.items.delete=確定要刪除所選項目嗎?
pane.items.delete.multiple=確定要刪除所選眾項目嗎?
-pane.items.remove.title=Remove from Collection
-pane.items.remove=Are you sure you want to remove the selected item from this collection?
-pane.items.remove.multiple=Are you sure you want to remove the selected items from this collection?
-pane.items.menu.remove=Remove Item from Collection…
-pane.items.menu.remove.multiple=Remove Items from Collection…
+pane.items.remove.title=從文獻庫中移除
+pane.items.remove=您確定要從文獻庫中移除所選項目嗎?
+pane.items.remove.multiple=您確定要從文獻庫中移除所選項目嗎?
+pane.items.menu.remove=從文獻庫中移除此項目...
+pane.items.menu.remove.multiple=從文獻庫中移除此項目...
pane.items.menu.moveToTrash=將項目移到垃圾筒…
pane.items.menu.moveToTrash.multiple=將眾項目移到垃圾筒…
pane.items.menu.export=匯出項目…
@@ -225,7 +225,7 @@ pane.items.menu.createParent=建立上層(parent)項目
pane.items.menu.createParent.multiple=建立眾上層(parent)項目
pane.items.menu.renameAttachments=以上層屬性資料重新命名
pane.items.menu.renameAttachments.multiple=以上層屬性資料重新命名
-pane.items.showItemInLibrary=Show Item in Library
+pane.items.showItemInLibrary=於文獻庫中顯示此項目
pane.items.letter.oneParticipant=寄給 %S 的信件
pane.items.letter.twoParticipants=寄給 %S 及 %S 的信件
@@ -566,15 +566,15 @@ zotero.preferences.export.quickCopy.exportFormats=匯出格式
zotero.preferences.export.quickCopy.instructions=快速複製:按快鍵(%S)複製所選參考文獻條到剪貼簿,或者拖放項目到網頁的文字輸入區。
zotero.preferences.export.quickCopy.citationInstructions=For bibliography styles, you can copy citations or footnotes by pressing %S or holding down Shift before dragging items.
-zotero.preferences.wordProcessors.installationSuccess=Installation was successful.
-zotero.preferences.wordProcessors.installationError=Installation could not be completed because an error occurred. Please ensure that %1$S is closed, and then restart %2$S.
-zotero.preferences.wordProcessors.installed=The %S add-in is currently installed.
-zotero.preferences.wordProcessors.notInstalled=The %S add-in is not currently installed.
-zotero.preferences.wordProcessors.install=Install %S Add-in
-zotero.preferences.wordProcessors.reinstall=Reinstall %S Add-in
-zotero.preferences.wordProcessors.installing=Installing %S…
-zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S is incompatible with versions of %3$S before %4$S. Please remove %3$S, or download the latest version from %5$S.
-zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S requires %3$S %4$S or later to run. Please download the latest version of %3$S from %5$S.
+zotero.preferences.wordProcessors.installationSuccess=安裝成功
+zotero.preferences.wordProcessors.installationError=因錯誤發生而無法完成安裝,請確認 %1$S 已關閉,而後重新開啟 %2$S。
+zotero.preferences.wordProcessors.installed=已經安裝 %S
+zotero.preferences.wordProcessors.notInstalled=未安裝 %S
+zotero.preferences.wordProcessors.install=安裝 %S
+zotero.preferences.wordProcessors.reinstall=重新安裝 %S
+zotero.preferences.wordProcessors.installing=安裝 %S 中...
+zotero.preferences.wordProcessors.incompatibleVersions1=%1$S %2$S 不相容於 %3$S 及舊過 %4$S 之版本,請移除 %3$S 版或從 %5$S 下載最新版本。
+zotero.preferences.wordProcessors.incompatibleVersions2=%1$S %2$S 需要 %3$S %4$S 或更新版本來執行,請由 %5$S 下載最新之 %3$S 版本。
zotero.preferences.styles.addStyle=新增樣式
@@ -738,7 +738,7 @@ integration.missingItem.multiple=引用文獻條中的 %1$S 項已不在 Zotero
integration.missingItem.description=按「否」會將包含此項目的引用文獻條的欄位碼刪除,保留引用文獻條的文字但會從參考文獻表中將它刪去。
integration.removeCodesWarning=移除欄位碼會使 Zotero 無法更新這個文件中的引用文獻條及參考文獻表。. 要繼續嗎?
integration.upgradeWarning=文件檔得升級才能使用 Zotero 2.1 或更新的版本。繼續之前最好先備份。要繼續嗎?
-integration.error.newerDocumentVersion=Your document was created with a newer version of Zotero (%1$S) than the currently installed version (%2$S). Please upgrade Zotero before editing this document.
+integration.error.newerDocumentVersion=您的文件由較Zotero (%2$S) 版本新的 (%1$S) 版本所建立,請在編輯此文件前更新Zotero。
integration.corruptField=用來告訴 Zotero 這個引用文獻條在文獻庫中代表的那一個項目的 Zotero 欄位碼已損毀。要重選這個項目嗎?
integration.corruptField.description=按「否定」將刪除包含此項目的引用文獻條的欄位碼,保留引用文獻文字但可能將欄位碼由參考文獻表中刪除。
integration.corruptBibliography=參考文獻表的 Zotero 欄位碼已損毀。要 Zotero 清除這個欄位碼並產生一個新的參考文獻表嗎?
@@ -770,8 +770,8 @@ sync.removeGroupsAndSync=移除群組與同步
sync.localObject=本機的物件
sync.remoteObject=遠端的物件
sync.mergedObject=合併的物件
-sync.merge.resolveAllLocal=Use the local version for all remaining conflicts
-sync.merge.resolveAllRemote=Use the remote version for all remaining conflicts
+sync.merge.resolveAllLocal=所有不同皆使用本機版本
+sync.merge.resolveAllRemote=所有不同皆使用遠端版本
sync.error.usernameNotSet=沒有設定使用者名稱
@@ -988,11 +988,11 @@ firstRunGuidance.quickFormatMac=輸入標題或作者以找出參考文獻條。
firstRunGuidance.toolbarButton.new=按此以開啟 Zotero,或用 %S 快鍵。
firstRunGuidance.toolbarButton.upgrade=Firefox 工具列上可看到 Zotero 圖示了。按圖示以開啟 Zotero,或用 %S 快鍵。
-styles.bibliography=Bibliography
-styles.editor.save=Save Citation Style
-styles.editor.warning.noItems=No items selected in Zotero.
-styles.editor.warning.parseError=Error parsing style:
-styles.editor.warning.renderError=Error generating citations and bibliography:
-styles.editor.output.individualCitations=Individual Citations
-styles.editor.output.singleCitation=Single Citation (with position "first")
-styles.preview.instructions=Select one or more items in Zotero and click the "Refresh" button to see how these items are rendered by the installed CSL citation styles.
+styles.bibliography=參考文獻表
+styles.editor.save=儲存文獻之樣式:
+styles.editor.warning.noItems=未於Zotero中選取任何項目
+styles.editor.warning.parseError=格式分析錯誤:
+styles.editor.warning.renderError=錯誤建立引用及參考文獻:
+styles.editor.output.individualCitations=單獨引用
+styles.editor.output.singleCitation=單一引用(具position "first"者)
+styles.preview.instructions=於Zotero中選取一個或多個項目,並點擊"重新整理"鍵可檢視這些項目會如何由安裝好的文獻格式所呈現。
diff --git a/test/runtests.sh b/test/runtests.sh
index 99575c4e6f..98f3c6ec6d 100755
--- a/test/runtests.sh
+++ b/test/runtests.sh
@@ -85,6 +85,7 @@ user_pref("extensions.zotero.debug.log", $DEBUG);
user_pref("extensions.zotero.debug.time", $DEBUG);
user_pref("extensions.zotero.firstRunGuidance", false);
user_pref("extensions.zotero.firstRun2", false);
+user_pref("extensions.zotero.reportTranslationFailure", false);
EOF
# -v flag on Windows makes Firefox process hang
diff --git a/chrome/content/zotero/xpcom/translation/translate.js b/chrome/content/zotero/xpcom/translation/translate.js
index 8067f05126..e30d9ae3ba 100644
--- a/chrome/content/zotero/xpcom/translation/translate.js
+++ b/chrome/content/zotero/xpcom/translation/translate.js
@@ -2080,17 +2080,23 @@ Zotero.Translate.Export.prototype.Sandbox = Zotero.Translate.Sandbox._inheritFro
* @param {Zotero.Item[]} items
*/
Zotero.Translate.Export.prototype.setItems = function(items) {
- this._items = items;
- delete this._collection;
+ this._export = {type: 'items', items: items};
}
/**
- * Sets the collection to be exported (overrides setItems)
+ * Sets the group to be exported (overrides setItems/setCollection)
+ * @param {Zotero.Group[]} group
+ */
+Zotero.Translate.Export.prototype.setLibraryID = function(libraryID) {
+ this._export = {type: 'library', id: libraryID};
+}
+
+/**
+ * Sets the collection to be exported (overrides setItems/setGroup)
* @param {Zotero.Collection[]} collection
*/
Zotero.Translate.Export.prototype.setCollection = function(collection) {
- this._collection = collection;
- delete this._items;
+ this._export = {type: 'collection', collection: collection};
}
/**
@@ -2157,15 +2163,21 @@ Zotero.Translate.Export.prototype._prepareTranslation = function() {
this._itemGetter = new Zotero.Translate.ItemGetter();
var configOptions = this._translatorInfo.configOptions || {},
getCollections = configOptions.getCollections || false;
- if(this._collection) {
- this._itemGetter.setCollection(this._collection, getCollections);
- delete this._collection;
- } else if(this._items) {
- this._itemGetter.setItems(this._items);
- delete this._items;
- } else {
- this._itemGetter.setAll(getCollections);
+ switch (this._export.type) {
+ case 'collection':
+ this._itemGetter.setCollection(this._export.collection, getCollections);
+ break;
+ case 'items':
+ this._itemGetter.setItems(this._export.items);
+ break;
+ case 'library':
+ this._itemGetter.setAll(this._export.id, getCollections);
+ break;
+ default:
+ throw new Error('No export set up');
+ break;
}
+ delete this._export;
// export file data, if requested
if(this._displayOptions["exportFileData"]) {